# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
import wx.dataview

from Config.Init import *
import Res.Allicons as icon

import Database.PostGet as PG
#import Database.PostGet2 as PG2

from AI.Analiz import *
import AI.DBgen as DBG
import AI.OpnSrc as OS

_ = wx.GetTranslation

###########################################################################
## Class MyPanel6
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__(self, parent, For_This_Frame=[], id=wx.ID_ANY, pos=wx.DefaultPosition, size=wx.Size(500, 450), style=wx.TAB_TRAVERSAL, name=wx.EmptyString):
		wx.Panel.__init__(self, parent, id=id, pos=pos, size=size, style=style, name=name)

		self.config = wx.GetApp().GetConfig()
		if int(self.config.Read('DBtype')) == 2:
			self.TDBE = 'mysql'
		elif int(self.config.Read('DBtype')) == 3:
			self.TDBE = 'post'
		elif int(self.config.Read('DBtype')) == 4:
			self.TDBE = 'orcl'
		else:
			self.TDBE = 'sqlite'


		Vsz1 = wx.BoxSizer(wx.VERTICAL)
		self.FTF = For_This_Frame

		self.Splt1 = wx.SplitterWindow( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.SP_3D| wx.SP_LIVE_UPDATE| wx.SP_NO_XP_THEME| wx.SP_THIN_SASH)
		self.Splt1.Bind(wx.EVT_IDLE, self.Splt1OnIdle)

		self.P1 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL)
		Vsz2 = wx.BoxSizer(wx.VERTICAL)

		self.lbl0 = wx.StaticText( self.P1, wx.ID_ANY, _(u"Select database"), wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl0.Wrap(-1)

		Vsz2.Add( self.lbl0, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )

		if self.TDBE == 'sqlite':
			self.dbfile = wx.FilePickerCtrl( self.P1, wx.ID_ANY, wx.EmptyString, _(u"Select Database file"), u"*.*", wx.DefaultPosition, wx.DefaultSize, wx.FLP_DEFAULT_STYLE|wx.FLP_OPEN|wx.FLP_SMALL )
			Vsz2.Add( self.dbfile, 0, wx.ALL|wx.EXPAND, 5 )

		if self.TDBE == 'mysql':
			self.idbfl2 = PG.Get2(u'', u'', u'')
			dbChoices = [db[0] for db in self.idbfl2.GetFromString(" SHOW DATABASES; ") ]
			self.dbBox1 = wx.Choice(self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, dbChoices, 0)
			Vsz2.Add(self.dbBox1, 0, wx.ALL | wx.EXPAND, 5)

		if self.TDBE == 'post':
			self.idbfl2 = PG.Get2(u'', u'', u'')
			dbChoices = [db[0] for db in self.idbfl2.GetFromString(" SELECT datname FROM pg_database; ") ]
			self.dbBox1 = wx.Choice(self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, dbChoices, 0)
			Vsz2.Add(self.dbBox1, 0, wx.ALL | wx.EXPAND, 5)

		if self.TDBE == 'orcl':
			self.idbfl2 = PG.Get2(u'', u'', u'')
			dbChoices = [db[0] for db in self.idbfl2.GetFromString("  ") ]
			self.dbBox1 = wx.Choice(self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, dbChoices, 0)
			Vsz2.Add(self.dbBox1, 0, wx.ALL | wx.EXPAND, 5)



		self.lbl1 = wx.StaticText( self.P1, wx.ID_ANY, _(u"List of Tabel:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl1.Wrap( -1 )

		Vsz2.Add( self.lbl1, 0, wx.ALL, 5 )

		self.DVC1 = wx.dataview.TreeListCtrl( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TR_HAS_BUTTONS|wx.TR_DEFAULT_STYLE )
		self.Col1 = self.DVC1.AppendColumn( _(u"Name"), 160,  wx.ALIGN_LEFT, wx.dataview.DATAVIEW_COL_RESIZABLE )
		self.Col2 = self.DVC1.AppendColumn( _(u"Type"), 70,  wx.ALIGN_LEFT, wx.dataview.DATAVIEW_COL_RESIZABLE )
		#self.Col3 = self.DVC1.AppendColumn( u"Name", 0,  wx.ALIGN_LEFT, wx.dataview.DATAVIEW_COL_RESIZABLE )
		Vsz2.Add( self.DVC1, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn1.SetBitmap( wx.Bitmap( ICON16_PATH + u'table_row_insert.png', wx.BITMAP_TYPE_ANY ) )
		self.btn1.SetBitmap(icon.table_row_insert.GetBitmap())
		self.btn1.SetToolTip( _(u"Insert") )

		Hsz1.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn2.SetBitmap(wx.Bitmap(ICON16_PATH + u'table_refresh.png', wx.BITMAP_TYPE_ANY))
		self.btn2.SetBitmap(icon.table_refresh.GetBitmap())
		self.btn2.SetToolTip(_(u"Update"))

		Hsz1.Add( self.btn2, 0, wx.ALL, 5 )

		self.btn3 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn3.SetBitmap(wx.Bitmap(ICON16_PATH + u'table_row_delete.png', wx.BITMAP_TYPE_ANY))
		self.btn3.SetBitmap(icon.table_row_delete.GetBitmap())
		self.btn3.SetToolTip(_(u"Delete"))

		Hsz1.Add( self.btn3, 0, wx.ALL, 5 )

		self.btn4 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn4.SetBitmap(wx.Bitmap(ICON16_PATH + u'table_relationship.png', wx.BITMAP_TYPE_ANY))
		self.btn4.SetBitmap(icon.table_relationship.GetBitmap())
		self.btn4.SetToolTip(_(u"Join"))

		Hsz1.Add( self.btn4, 0, wx.ALL, 5 )

		self.btn5 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn5.SetBitmap(wx.Bitmap(ICON16_PATH + u'table_import.png', wx.BITMAP_TYPE_ANY))
		self.btn5.SetBitmap(icon.table_import.GetBitmap())
		self.btn5.SetToolTip(_(u"Brows"))

		Hsz1.Add( self.btn5, 0, wx.ALL, 5 )

		self.btn6 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn6.SetBitmap(wx.Bitmap(ICON16_PATH + u'accept_button.png', wx.BITMAP_TYPE_ANY))
		self.btn6.SetBitmap(icon.accept_button.GetBitmap())
		self.btn6.SetToolTip(_(u"Apply"))

		Hsz1.Add( self.btn6, 0, wx.ALL, 5 )

		self.btn7 = wx.BitmapButton(self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn7.SetBitmap(wx.Bitmap(ICON16_PATH + u'table_lightning.png', wx.BITMAP_TYPE_ANY))
		self.btn7.SetBitmap(icon.table_lightning.GetBitmap())
		self.btn7.SetToolTip(_(u"Generate"))
		Hsz1.Add(self.btn7, 0, wx.ALL, 5)


		Vsz2.Add( Hsz1, 0, wx.EXPAND, 5 )


		self.P1.SetSizer( Vsz2 )
		self.P1.Layout()
		Vsz2.Fit( self.P1 )
		self.P2 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz3 = wx.BoxSizer( wx.VERTICAL )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl3 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Method in program"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs1Choices = [ u"set", u"get", u"both" ]
		self.chs1 = wx.Choice( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs1Choices, 0 )
		self.chs1.SetSelection( 2 )
		Hsz2.Add( self.chs1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz2, 0, wx.EXPAND, 5 )

		self.fldinit = wx.TextCtrl(self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize,
		                           wx.HSCROLL|wx.TE_MULTILINE|wx.TE_WORDWRAP )
		Vsz3.Add(self.fldinit, 1, wx.ALL | wx.EXPAND, 5)

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl4 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Program Statments"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl4.Wrap( -1 )

		Hsz3.Add( self.lbl4, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnps = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz3.Add( self.btnps, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz3, 0, wx.EXPAND, 5 )

		self.fldprg = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.HSCROLL|wx.TE_MULTILINE|wx.TE_WORDWRAP )
		Vsz3.Add( self.fldprg, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl5 = wx.StaticText( self.P2, wx.ID_ANY, _(u"SQL  Statments"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl5.Wrap( -1 )

		Hsz4.Add( self.lbl5, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnss = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz4.Add( self.btnss, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz4, 0, wx.EXPAND, 5 )

		self.fldsql = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.HSCROLL|wx.TE_MULTILINE|wx.TE_WORDWRAP )
		Vsz3.Add( self.fldsql, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )

		self.btncv = wx.Button( self.P2, wx.ID_ANY, _(u"To CVS"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz5.Add( self.btncv, 0, wx.ALL, 5 )

		self.btnxl = wx.Button( self.P2, wx.ID_ANY, _(u"To Excel"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz5.Add( self.btnxl, 0, wx.ALL, 5 )

		self.btnex = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		self.btnex.SetToolTip( _(u"Extended") )

		Hsz5.Add( self.btnex, 0, wx.ALL, 5 )

		Vsz3.Add( Hsz5, 0, wx.EXPAND, 5 )

		self.P2.SetSizer( Vsz3 )
		self.P2.Layout()
		Vsz3.Fit( self.P2 )
		self.Splt1.SplitVertically( self.P1, self.P2, 255 )
		Vsz1.Add( self.Splt1, 1, wx.EXPAND, 5 )

		self.SetSizer( Vsz1 )
		self.Layout()


		#Parameter init
		self.table = u''
		self.field = u''
		self.data = u''
		self.sqfile = u''

		# Init program
		self.fromHere()

		# Connect Events
		if self.TDBE == 'sqlite':
			self.dbfile.Bind(wx.EVT_FILEPICKER_CHANGED, self.dbopn)
		if self.TDBE == 'mysql' or self.TDBE == 'post':
			self.dbBox1.Bind( wx.EVT_CHOICE, self.usedb )
		self.DVC1.Bind(wx.dataview.EVT_TREELIST_ITEM_CHECKED, self.chkit)
		self.btn1.Bind( wx.EVT_BUTTON, self.insit )
		self.btn2.Bind( wx.EVT_BUTTON, self.updit )
		self.btn3.Bind( wx.EVT_BUTTON, self.delit )
		self.btn4.Bind( wx.EVT_BUTTON, self.jinit )
		self.btn5.Bind( wx.EVT_BUTTON, self.brwit )
		self.btn6.Bind( wx.EVT_BUTTON, self.aplit )
		self.btn7.Bind( wx.EVT_BUTTON, self.gnrit )

		self.chs1.Bind( wx.EVT_CHOICE, self.chgmtd )
		self.btnps.Bind( wx.EVT_BUTTON, self.prgstm )
		self.btnss.Bind( wx.EVT_BUTTON, self.sqlstm )
		self.btncv.Bind( wx.EVT_BUTTON, self.tocvs )
		self.btnxl.Bind( wx.EVT_BUTTON, self.toexl )
		self.btnex.Bind( wx.EVT_BUTTON, self.extnd )

	def __del__( self ):
		pass

	# Virtual event handlers, overide them in your derived class
	def fromHere(self):
		if len(self.FTF) > 0:
			frmname = self.FTF[0].GetTitle()

			lbl0 = self.lbl0.GetLabel()
			nlbl = lbl0 + ' from ' + frmname
			#print(frmname)
			self.lbl0.SetLabel(nlbl)
			if self.FTF[1] != '' and self.TDBE == 'sqlite':
				self.dbfil = self.FTF[1]
				self.dbfile.SetPath(self.dbfil)
				self.idbfl2 = PG.Get2(self.dbfil, u'', u'')
				self.dbdata = self.idbfl2.GetFromString('select * from sqlite_master')
				self.DVC1.DeleteAllItems()
				self.filllist()
				self.chgmtd(None)
			if self.FTF[1] != '' and self.TDBE in ['mysql','post']:
				self.dbfil = self.FTF[1]
				self.dbBox1.SetStringSelection(self.dbfil)
				self.usedb(None)



	def dbopn(self, event):
		if self.TDBE == 'sqlite':
			dbftype = Database_type[int(self.config.Read('DBtype'))]
			self.dbfil = self.dbfile.GetPath()
			self.idbfl2 = PG.Get2(self.dbfil, u'',u'')
			self.dbdata = self.idbfl2.GetFromString('select * from sqlite_master')
			self.DVC1.DeleteAllItems()
			self.filllist()
			self.chgmtd(None)

	def usedb(self, event):
		thsdbuse = self.dbBox1.GetStringSelection()
		self.idbfl2 = PG.Get2(thsdbuse, u'', u'')
		tbles = ''
		if self.TDBE == 'mysql':
			self.idbfl2.GetCommandStr(thsdbuse,' USE %s; '%thsdbuse )
			tbles = self.idbfl2.GetFromString(' SHOW FULL TABLES; ')

		if self.TDBE == 'post':
			#self.idbfl2 = PG.Get2.GetCommandStr(thsdbuse,"SELECT * FROM pg_catalog.pg_tables WHERE schemaname != 'pg_catalog' AND  schemaname != 'information_schema';" )
			stinfsql = " SELECT tablename, schemaname FROM pg_catalog.pg_tables WHERE schemaname != 'pg_catalog' AND schemaname != 'information_schema'; "
			tabel = self.idbfl2.GetFromString(stinfsql)
			#print(self.idbfl2 , tabel)
			tbles = tabel
			#tbles = self.idbfl2.GetFromString(' \dt ')

		#print(tbles)
		self.dbdata = tbles
		self.DVC1.DeleteAllItems()
		self.filllist2()
		self.chgmtd(None)


	def filllist(self):
		Droot = self.DVC1.GetRootItem()
		self.troot = self.DVC1.AppendItem(Droot,"Table")
		self.iroot = self.DVC1.AppendItem(Droot,"Indices")
		self.Tfilds, self.Indxss = AnalizdbText2(self.dbdata)
		#print(Tfilds)
		for tb in self.Tfilds:
			tbl = self.DVC1.AppendItem(self.troot, tb)
			for fld in self.Tfilds[tb]:
				ifld = self.DVC1.AppendItem(tbl, fld[0])
				self.DVC1.SetItemText(ifld, 0, fld[0])
				self.DVC1.SetItemText(ifld, 1, fld[1])

	def filllist2(self):
		self.Tfilds = {}
		Droot = self.DVC1.GetRootItem()
		self.troot = self.DVC1.AppendItem(Droot, "Table")
		for tb in self.dbdata:
			tbl = self.DVC1.AppendItem(self.troot, tb[0])
			self.DVC1.SetItemText(tbl, 0, tb[0])
			self.DVC1.SetItemText(tbl, 1, tb[1])
			if self.TDBE == 'mysql':
				fldlst = []
				for col in self.idbfl2.GetFromString(" DESC %s" %tb[0]):
					ifld = self.DVC1.AppendItem(tbl, col[0])
					self.DVC1.SetItemText(ifld, 0, col[0])
					self.DVC1.SetItemText(ifld, 1, col[1])
					fldlst.append((col[0],col[1]))
				self.Tfilds[tb[0]] = fldlst
			if self.TDBE == 'post':
				fldlst = []
				for col in self.idbfl2.GetFromString(" SELECT column_name, data_type FROM information_schema.columns WHERE TABLE_NAME = '%s' " %tb[0]):
					ifld = self.DVC1.AppendItem(tbl, col[0])
					self.DVC1.SetItemText(ifld, 0, col[0])
					self.DVC1.SetItemText(ifld, 1, col[1])
					fldlst.append((col[0], col[1]))
				self.Tfilds[tb[0]] = fldlst

			#for fld in self.Tfilds[tb]:

	def chkit(self, event):
		self.gtslt = self.DVC1.GetSelections()
		itmtxt = self.DVC1.GetItemText(self.gtslt[0], 0)
		if itmtxt in [f[0] for fl in self.Tfilds.values() for f in fl ]:
			prnt = self.DVC1.GetItemParent(self.gtslt[0])
			if self.DVC1.AreAllChildrenInState(prnt,1):
				self.DVC1.CheckItem(prnt, 1)
			else:
				self.DVC1.CheckItem(prnt, 2)
			#if self.Tfilds[self.DVC1.GetItemText(prnt, 0)]
			#print(self.DVC1.AreAllChildrenInState(prnt,1))
		if itmtxt in self.Tfilds:
			flds = [f[0] for f in self.Tfilds[itmtxt]]
			if self.DVC1.GetCheckedState(self.gtslt[0]) == 1:
				self.DVC1.CheckItemRecursively(self.gtslt[0], 1)
			elif self.DVC1.GetCheckedState(self.gtslt[0]) == 0:
				self.DVC1.CheckItemRecursively(self.gtslt[0], 0)

	def ChkTicks(self):
		frstitm = self.DVC1.GetRootItem()
		nxitm = self.DVC1.GetNextItem(frstitm)
		tbltiklst = {}
		fldtiklst = []
		#print(self.DVC1.GetItemText(nxitm, 0),self.DVC1.GetCheckedState(nxitm))
		# if self.DVC1.GetCheckedState(frstitm):
		# 	self.DVC1.CheckItemRecursively(frstitm,1)
		# else:
		# 	self.DVC1.UncheckItem(frstitm)
		for fld in self.Tfilds:
			nxitm = self.DVC1.GetNextItem(nxitm)
			tblnm = u''
			if self.DVC1.GetCheckedState(nxitm):
				tblnm = self.DVC1.GetItemText(nxitm, 0)
			fldtiklst = []
			for f in self.Tfilds[fld]:
				nxitm = self.DVC1.GetNextItem(nxitm)
				if self.DVC1.GetCheckedState(nxitm):
					fldtiklst.append(self.DVC1.GetItemText(nxitm, 0))
				#tbltiklst.append(self.DVC1.GetItemText(nxitm, 0))
			if tblnm != u'':
				tbltiklst[tblnm] = fldtiklst

		return tbltiklst

	def insit( self, event ):
		#self.gtslt = self.DVC1.GetSelections()
		#itmtxt = self.DVC1.GetItemText(self.gtslt[0], 0)
		sqlsnts = self.ChkTicks()
		txt = u''
		for tbl in sqlsnts.keys():
			txt += '\n'
			txt += u"\tself.MySet.Tabel = '%s' \n"%tbl
			fild = u''
			for fld in sqlsnts.get(tbl):
				fild += fld + ','
			txt += u'\t#AllData = ['
			for d in range(len(sqlsnts.get(tbl))):
				txt += u' Data%d' %d + ','
			txt = txt.rstrip(',')
			txt += u'] #You can add data to put here\n'
			txt += u'\tself.MySet.Addrecord( " '+fild.rstrip(',')+ u' ", AllData )\n'

		#print(txt)
		self.fldprg.SetValue(txt)

	def updit( self, event ):
		sqlsnts = self.ChkTicks()
		smfild = [ f for fld in sqlsnts.values() for f in fld ]
		#print(sqlsnts,'\n',smfild)
		frm = wx.Dialog(self, -1)
		pnl = MyPanel3(frm, smfild)
		frm.SetSize((400, 125))
		frm.SetLabel(_(u'Select Key feild'))
		frm.ShowModal()
		if pnl.acept:
			choic = pnl.chs2.GetStringSelection()
		else:
			choic = ''

		frm.Destroy()
		txt = u''
		for tbl in sqlsnts.keys():
			txt += '\n'
			txt += u"\tself.MySet.Tabel = '%s' \n" % tbl
			fild = u''
			contor = 0
			for fld in sqlsnts.get(tbl):
				if fld != choic:
					fild += fld + '=? ,'
					contor += 1
			txt += u'\t#AllData = ['
			Data = u''
			for d in range(contor):
				Data += u' Data%d' %d + ','
			Data = Data.rstrip(',')
			#print(Data)
			txt += Data + u'] #You can add data to put here\n'
			txt += u'\t#self.KeyData = #can put need data here\n'
			txt += u'\tself.MySet.Updaterecord( " ' + fild.rstrip(',')
			txt += ' Where '+ choic + ' = %s " %self.KeyData , AllData )\n'

		self.fldprg.SetValue(txt)

		event.Skip()

	def delit( self, event ):
		sqlsnts = self.ChkTicks()
		smfild = [f for fld in sqlsnts.values() for f in fld]
		# print(sqlsnts,'\n',smfild)
		frm = wx.Dialog(self, -1)
		pnl = MyPanel3(frm, smfild)
		frm.SetSize((400, 125))
		frm.SetLabel(_(u'Select Key feild'))
		frm.ShowModal()
		if pnl.acept:
			choic = pnl.chs2.GetStringSelection()
		else:
			choic = ''

		frm.Destroy()
		txt = u''
		for tbl in sqlsnts.keys():
			txt += '\n'
			txt += u"\tself.MySet.Tabel = '%s' \n" % tbl

			txt += u'\t#self.KeyData = #can put need data here\n'
			txt += u'\tself.MySet.Deleterecord( " ' #+ fild.rstrip(',')
			txt += choic + ' = %s " %self.KeyData ) \n'
			#txt += ' Where ' + choic + ' = %s " %self.KeyData , AllData )\n'

		self.fldprg.SetValue(txt)
		event.Skip()

	def jinit( self, event ):
		#print(self.ChkTicks())
		sqlsnts = self.ChkTicks()
		Join = ''
		Jkey = []
		Tbls = [T for T in sqlsnts.keys()]
		Bchs = False
		Btbl = u''
		for i in range(len(Tbls)-1):
			frm = wx.Dialog(self, -1)
			pnl = MyPanel5(frm, sqlsnts)
			frm.SetSize((550, 155))
			frm.SetLabel(_(u'Select Key feild'))
			if Bchs:
				pnl.chs1.SetStringSelection(Btbl)
				pnl.chs1.Disable()
				pnl.chs2.SetItems([Btbl+'.'+f for f in sqlsnts[Btbl]])
				pnl.chs3.SetItems([Tbls[0]+'.'+f for f in sqlsnts[Tbls[0]]] )
			frm.ShowModal()
			if pnl.acept:
				if i == 0:
					Btbl = pnl.chs1.GetStringSelection()
					Tbls.remove(Btbl)
					Bchs = True
				else:
					pass
				Jkey.append(pnl.chs2.GetStringSelection()+' = '+pnl.chs3.GetStringSelection())
				Jslc = pnl.chs3.GetStringSelection().split('.')[0]
				Tbls.remove(Jslc)
				#print(Tbls,Jslc)
			else:
				break
			frm.Destroy()
		#print(Btbl, Jkey)
		Join += " Select "
		Fields = [T+'.'+F for T in sqlsnts.keys() for F in sqlsnts[T]]
		#print(Fields)
		for Fld in Fields:
			Join += Fld + ' ,'
		Join = Join.rstrip(',')
		Join += " From "+Btbl+"\n"
		for J in Jkey:
			Join += " Inner Join " + J.split('=')[-1].split('.')[0] + " On " + J + "\n"
		#print(Join)
		self.fldsql.SetValue(Join)

		#self.fldsql.SetValue(sqltxt)

	def brwit( self, event ):

		#dbtype = Database_type[int(self.config.Read('DBtype'))]
		self.gtslt = self.DVC1.GetSelections()
		if self.fldsql.GetValue() != u'':
			sqlcomnd = self.fldsql.GetValue()
			#brsdb = PG2.Get(self.dbfil, dbtype)
			brsdb = PG.Get2(self.dbfil, u'',u'')
			#brsdb = PG.Get(self.dbfil, u'', u'')
			self.idata = brsdb.GetFromString(sqlcomnd)
			if len(self.idata) == 0:
				wx.MessageBox("0 row in %s"%sqlcomnd)
				thsfld = []
			else:
				thsfld = self.idata[0].keys()

		else:
			thsfld = []
			if self.DVC1.GetItemText(self.gtslt[0], 1) == '' and self.DVC1.GetItemText(self.gtslt[0], 0) not in ['Table','Indices']:
				myfild = self.DVC1.GetItemText(self.gtslt[0], 0)
				#print(self.ChkTicks())
				if len(self.ChkTicks()) > 0:
					thstbl = [T for T in self.ChkTicks().keys()]
					thsfld = [t+'.'+F for t in self.ChkTicks() for F in self.ChkTicks()[t]]
					ftxt = ' ,'.join(thsfld)
					Ttxt = ' ,'.join(thstbl)
					#print(ftxt,thsfld,thstbl)
					self.idbfl = PG.Get2(self.dbfil, u'', u'')
					self.idata = self.idbfl.GetFromString(u'select %s from %s' %(ftxt,Ttxt))

				else:
					for fld in self.Tfilds:
						if myfild == fld:
							thsfld = [f[0] for f in self.Tfilds[fld]]
					self.idbfl = PG.Get2(self.dbfil, u'', u'')
					#self.idbfl = PG2.Get(self.dbfil, dbtype)
					self.idata = self.idbfl.GetFromString(u' select * from %s' % myfild)
			else:
				if self.TDBE == 'mysql' or self.TDBE == 'post':
					itbl = self.DVC1.GetItemText(self.gtslt[0], 0)
					self.idata = self.idbfl2.GetFromString(u" select * from %s" %itbl )
					#print(self.Tfilds,self.idata)
					for fld in self.Tfilds:
						if itbl == fld:
							thsfld = [str(f[0]) for f in self.Tfilds[fld]]
				else:
					self.idata = []
					thsfld = []
		#print(thsfld,self.idata)
		if len(thsfld) > 0 and len(self.idata) > 0 :
			frm = wx.Dialog(self, -1)
			pnl = MyPanel2(frm, thsfld, self.idata)
			frm.SetSize((600, 300))
			frm.SetLabel(_(u'Select Table'))
			frm.ShowModal()

			frm.Destroy()

	def aplit( self, event ):
		pdwf = wx.FindWindowByName("Program Develop")
		#print(dir(pdwf))
		pitm = pdwf.DVC1.GetSelection()
		pdtxt = pdwf.DVC1.GetItemText(pitm,0)
		pdcod = pdwf.DVC1.GetItemText(pitm,1)
		pdfil = pdwf.thsfile
		pdpth = pdwf.thspath
		#print(pdtxt,pdcod,pdfil,pdpth)
		if self.fldinit.GetValue() != '':
			if pdcod != None or pdcod != '':
				if '.py' in pdfil :
					mycod = Anlzfil(pdfil)
					if not mycod.ishaspanel():
						wx.MessageBox(_("Please use wx.Panel in source file"))
						return 1
					#print(mycod.indexImpline())
					ex = 0
					for imlin,inx in mycod.indexImpline():
						if 'Database.PostGet' in imlin:
							ex = 1

					self.Frm = wx.Frame(self,
					                    style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
					self.Pnl = OS.SrcPanel(self.Frm, pdfil)
					self.Frm.SetMenuBar(OS.MyMenuBar1(u'Pro'))
					self.Frm.SetSize((700, 560))
					self.Frm.SetLabel(pdfil)
					self.Frm.Show()
					if ex == 0:
						linnum = mycod.indexImpline()[-1][1]
						#print(linnum)
						self.Pnl.SrcAlg.GotoLine(linnum+1)
						ipos = self.Pnl.SrcAlg.GetCurrentPos()
						#print(ipos,self.Pnl.SrcAlg.GetLastPosition())
						self.Pnl.SrcAlg.SetInsertionPoint(ipos-1)
						#self.Pnl.SrcAlg.SetInsertionPointEnd()
						self.Pnl.SrcAlg.AddText("\nimport Database.PostGet as PG\n")

					if mycod.isDBimexist():
						getit,postit = mycod.isFiledbexist()
						#print(getit,postit)
						print("If you change Database Please change it manually")
					else:
						#print(self.fldinit.GetValue())
						#print(self.Pnl.SrcAlg.GetCurrentPos())
						rsult=self.Pnl.SrcAlg.SearchInTarget('wx.Panel.__init__')
						self.Pnl.SrcAlg.SearchAnchor()
						if rsult == -1:
							self.Pnl.SrcAlg.SearchNext(1,'wx.Panel.__init__')
						npline=self.Pnl.SrcAlg.GetCurrentLine()
						#print(npline)
						self.Pnl.SrcAlg.GotoLine(npline + 2)
						ipos = self.Pnl.SrcAlg.GetCurrentPos()
						#print(ipos, self.Pnl.SrcAlg.GetLastPosition())
						self.Pnl.SrcAlg.SetInsertionPoint(ipos)
						self.Pnl.SrcAlg.AddText("\n")
						self.Pnl.SrcAlg.AddText(self.fldinit.GetValue())
						self.Pnl.SrcAlg.AddText("\n")
						wx.MessageBox(_("Please Add Program Statements to correct line of source file for Use database.\n"
						              "And Then Save file to Apply change.Do Not forget Save File!"))

				else:
					print(pdfil)
			else:
				print(pdcod,type(pdcod))
		else:
			print(u'Please select your database')
		event.Skip()

	def gnrit( self, event ):
		if self.fldsql.GetValue() != '':
			self.dlg = wx.FileDialog(self, _("Save as SQL file"),
			                         defaultDir=Src_dbf+SLASH+'sqls',
			                         defaultFile="",
			                         wildcard="SQL file(*.sql)|*.sql|All file(*.*)|*.*",
			                         style=wx.FD_SAVE | wx.FD_CHANGE_DIR | wx.FD_OVERWRITE_PROMPT)
			if self.dlg.ShowModal() == wx.ID_OK:
				sqlfpath = self.dlg.GetPaths()[0]
			else:
				return 1
			self.dlg.Destroy()
			with open(sqlfpath+'.sql','w+',encoding='utf-8') as f:
				f.write(self.fldsql.GetValue())
			wx.MessageBox(_("SQL file successful create in Src\DBF\sqls path."))

		event.Skip()

	def chgmtd( self, event ):
		dbf = Src_dbf + ''
		#inittxt = "## Add this lines to import part of program \nimport Database.PostGet as PG\n"
		inittxt = ''
		inittxt2 = "\t\t## Please Add this line in Panel __init__ function\n"
		if self.TDBE == 'sqlite':
			dbf = self.dbfil
		else:
			dbf = self.dbBox1.GetStringSelection()

		if self.table != '':
			table = self.table
		else:
			table = u''
		if self.field != '':
			field = self.field
		else:
			field = u''
		if self.data != '':
			data = self.dbdat
		else:
			data = u''
		if self.sqfile != '':
			file = self.sqfile
		else:
			file = u''
		if self.chs1.GetStringSelection() == 'set':
			self.fldinit.SetValue(inittxt+inittxt2+f"\t\tself.MySet = PG.Post2('{dbf}','{table}','{field}','{data}')\n".format(dbf,table,field,data))
		elif self.chs1.GetStringSelection() == 'get':
			self.fldinit.SetValue(inittxt+inittxt2+f"\t\tself.MyGet = PG.Get2('{dbf}','{data}','{file}')\n".format(dbf,data,file))
		elif self.chs1.GetStringSelection() == 'both':
			self.fldinit.SetValue(inittxt+inittxt2+f"\t\tself.MySet = PG.Post2('{dbf}','{table}','{field}','{data}')\n".format(dbf,table,field,data)
			                      +f"\t\tself.MyGet = PG.Get2('{dbf}','{data}','{file}')\n".format(dbf,data,file))
		else:
			print('What method is')
		if self.TDBE == 'mysql':
			#if self.chs1.GetStringSelection() == 'set':
			#	self.fldinit.SetValue(self.fldinit.GetValue()+f"\t\tself.MySet.GetCommandStr('{dbf}','USE {dbf};')\n".format(dbf,dbf))
			if self.chs1.GetStringSelection() == 'get':
				self.fldinit.SetValue(self.fldinit.GetValue() + f"\t\tself.MyGet.GetCommandStr('{dbf}','USE {dbf};')\n".format(dbf, dbf))
			elif self.chs1.GetStringSelection() == 'both':
				self.fldinit.SetValue(
					self.fldinit.GetValue() + #f"\t\tself.MySet.GetCommandStr('{dbf}','USE {dbf};')\n".format(dbf, dbf)+
				f"\t\tself.MyGet.GetCommandStr('{dbf}','USE {dbf};')\n".format(dbf, dbf))



	def prgstm( self, event ):
		txt1 = self.fldinit.GetValue()
		txt2 = self.fldprg.GetValue()
		#print(txt1+u'\n'+txt2)
		self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		if txt1 != u'':
			self.Pnl = DBG.TxtPanel(self.Frm)
			self.Pnl.Txt.SetValue(txt1+u'\n'+txt2)
			self.Frm.SetMenuBar(DBG.MyMenuBar2(u'prg'))
			self.Frm.Show()
		event.Skip()

	def sqlstm( self, event ):
		# txt1 = self.fldsql.GetValue()
		# #print(txt1)
		# self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		# if txt1 != u'':
		# 	self.Pnl = DBG.TxtPanel(self.Frm)
		# 	self.Pnl.Txt.SetValue(txt1)
		# 	self.Frm.SetMenuBar(DBG.MyMenuBar2(u'sql'))
		# 	self.Frm.Show()
		self.dlg = wx.FileDialog(self, _("Open sql file"),
		                         defaultDir=Src_dbf+SLASH+'sqls',
		                         defaultFile="",
		                         wildcard="SQL file(*.sql)|*.sql",
		                         style=wx.FD_OPEN |wx.FD_CHANGE_DIR )
		if self.dlg.ShowModal() == wx.ID_OK:
			sqlfil = self.dlg.GetPaths()[0]
		self.dlg.Destroy()
		with open(sqlfil,'r') as f:
			sqltxt = f.read()
		self.fldsql.SetValue(sqltxt)


		event.Skip()

	def tocvs( self, event ):
		import csv
		self.dlg = wx.FileDialog(self,_("Save as CSV file"),
		                         defaultDir=DATABASE_PATH,
		                         defaultFile="",
		                         wildcard="CSV file(*.csv)|*.csv|All file(*.*)|*.*",
		                         style=wx.FD_SAVE | wx.FD_CHANGE_DIR | wx.FD_OVERWRITE_PROMPT)
		if self.dlg.ShowModal() == wx.ID_OK:
			paths = self.dlg.GetPaths()[0]

		self.dlg.Destroy()
		#print(paths)
		sqlcomnd = self.fldsql.GetValue()
		brsdb = PG.Get2(self.dbfil, u'', u'')
		self.idata = brsdb.GetFromString(sqlcomnd)
		thsfld = [F.strip('`') for t in self.ChkTicks() for F in self.ChkTicks()[t]]
		with open(paths, 'w',newline='') as csvfile:
			filwrit = csv.writer(csvfile, delimiter=',',quotechar='|', quoting=csv.QUOTE_MINIMAL)
			filwrit.writerow(thsfld)
			for row in self.idata:
				filwrit.writerow(row)
		event.Skip()

	def toexl( self, event ):
		from xlsxwriter.workbook import Workbook
		self.dlg = wx.FileDialog(self, _("Save as Excel file"),
		                         defaultDir=DATABASE_PATH,
		                         defaultFile="",
		                         wildcard="Excel file(*.xlsx)|*.xlsx|All file(*.*)|*.*",
		                         style=wx.FD_SAVE | wx.FD_CHANGE_DIR | wx.FD_OVERWRITE_PROMPT)
		if self.dlg.ShowModal() == wx.ID_OK:
			paths = self.dlg.GetPaths()[0]
		self.dlg.Destroy()
		sqlcomnd = self.fldsql.GetValue()
		brsdb = PG.Get2(self.dbfil, u'', u'')
		self.idata = brsdb.GetFromString(sqlcomnd)

		workbook = Workbook(paths)
		worksheet = workbook.add_worksheet()
		r = 0

		for row in self.idata:
			c = 0
			for col in row:
				worksheet.write(r, c, col)
				c += 1
			r += 1
		workbook.close()
		event.Skip()

	def extnd( self, event ):
		wx.MessageBox(_("Please connect to our site and send your request"))
		event.Skip()

	def Splt1OnIdle( self, event ):
		self.Splt1.SetSashPosition( 255 )
		self.Splt1.Unbind( wx.EVT_IDLE )


###########################################################################
## Class MyPanel2
###########################################################################

class MyPanel2 ( wx.Panel ):

	def __init__( self, parent, fields, Data, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,300 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz = wx.BoxSizer( wx.VERTICAL )
		#self.DBF = DBF.split('\\')[-1]

		#self.idbfl = PG.Get(self.DBF, u'', u'')
		#self.idata = self.idbfl.GetFromString(u' select * from %s' %Table)
		self.idata = Data

		self.DVC1 = wx.dataview.DataViewListCtrl( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.dataview.DV_HORIZ_RULES|wx.dataview.DV_VERT_RULES )
		#self.fld1 = self.DVC1.AppendTextColumn( u"Name", 0, wx.DATAVIEW_CELL_INERT, -1, wx.ALIGN_LEFT, wx.DATAVIEW_COL_RESIZABLE )
		#self.fld2 = self.DVC1.AppendTextColumn( u"Name", 0, wx.DATAVIEW_CELL_INERT, -1, wx.ALIGN_LEFT, wx.DATAVIEW_COL_RESIZABLE )
		Vsz.Add( self.DVC1, 1, wx.ALL|wx.EXPAND, 5 )

		#for Col in range(len(self.idata[0])):
		#	self.DVC1.AppendTextColumn(u"field", -1 )
		for Col in fields:
			self.DVC1.AppendTextColumn(Col, -1 )

		for data in self.idata:
			DD = ()
			for d in data:
				DD = DD + (str(d),)
			self.DVC1.AppendItem(DD)


		self.m_button8 = wx.Button( self, wx.ID_ANY, _(u"ok"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz.Add( self.m_button8, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( Vsz )
		self.Layout()

		# Connect Events
		self.m_button8.Bind( wx.EVT_BUTTON, self.cols )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def cols( self, event ):
		q = self.GetParent()
		q.Close()


###########################################################################
## Class MyPanel3
###########################################################################

class MyPanel3 ( wx.Panel ):

	def __init__( self, parent,fldlst, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 396,124 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self, wx.ID_ANY, _(u"Key of Field UpDate"), wx.DefaultPosition, wx.Size( 120,-1 ), 0 )
		self.lbl2.Wrap( -1 )

		Hsz2.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs2Choices = fldlst
		self.chs2 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs2Choices, 0 )
		self.chs2.SetSelection( 0 )
		Hsz2.Add( self.chs2, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl3 = wx.StaticText( self, wx.ID_ANY, u"=", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.codfld = wx.TextCtrl(self, wx.ID_ANY, _(u"SomeData"), wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY)
		Hsz2.Add(self.codfld, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsz1.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )


		Hsz3.Add( ( 0, 0), 1, wx.EXPAND, 5 )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancle or Return"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Ok or Apply"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz3, 1, wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.aply )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def cncl( self, event ):
		self.acept = False
		q = self.GetParent()
		q.Close()

	def aply( self, event ):
		self.acept = True
		q = self.GetParent()
		q.Close()

###########################################################################
## Class MyPanel4
###########################################################################

class MyPanel4 ( wx.Panel ):

	def __init__( self, parent,tabls, flds1, flds2, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,175 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl1 = wx.StaticText( self, wx.ID_ANY, _(u"Base Table For Join"), wx.DefaultPosition, wx.Size( 120,-1 ), 0 )
		self.lbl1.Wrap( -1 )

		Hsz1.Add( self.lbl1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs1Choices = tabls
		self.chs1 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs1Choices, 0 )
		self.chs1.SetSelection( 0 )
		Hsz1.Add( self.chs1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz1, 1, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self, wx.ID_ANY, _(u"Key of Field For Join"), wx.DefaultPosition, wx.Size( 120,-1 ), 0 )
		self.lbl2.Wrap( -1 )

		Hsz2.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs2Choices = flds1
		self.chs2 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs2Choices, 0 )
		self.chs2.SetSelection( 0 )
		Hsz2.Add( self.chs2, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl3 = wx.StaticText( self, wx.ID_ANY, u"=", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs3Choices = flds2
		self.chs3 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs3Choices, 0 )
		self.chs3.SetSelection( 0 )
		Hsz2.Add( self.chs3, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		#self.chk1 = wx.CheckBox( self, wx.ID_ANY, u"Use All field", wx.DefaultPosition, wx.DefaultSize, 0 )
		#Hsz3.Add( self.chk1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Hsz3.Add( ( 0, 0), 1, wx.EXPAND, 5 )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancle & Return"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Ok & Apply"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz3, 1, wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		#self.chk1.Bind( wx.EVT_CHECKBOX, self.chkall )
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.aply )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	#def chkall( self, event ):
	#	event.Skip()

	def cncl( self, event ):
		self.acept = False
		q = self.GetParent()
		q.Close()

	def aply( self, event ):
		self.acept = True
		q = self.GetParent()
		q.Close()

###########################################################################
## Class MyPanel5
###########################################################################

class MyPanel5 ( wx.Panel ):

	def __init__( self, parent, Data, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 400,145 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.Data = Data

		Btbl = [T for T in Data.keys()]
		Bfld = [Btbl[0] + '.' + F for F in Data[Btbl[0]]]
		Jfld = [Btbl[1] + '.' + F for F in Data[Btbl[1]]]

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl1 = wx.StaticText( self, wx.ID_ANY, _(u"Base Table For Join"), wx.DefaultPosition, wx.Size( 120,-1 ), 0 )
		self.lbl1.Wrap( -1 )

		Hsz1.Add( self.lbl1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs1Choices = Btbl
		self.chs1 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs1Choices, 0 )
		self.chs1.SetSelection( 0 )
		Hsz1.Add( self.chs1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz1, 1, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self, wx.ID_ANY, _(u"Key of Field For Join"), wx.DefaultPosition, wx.Size( 120,-1 ), 0 )
		self.lbl2.Wrap( -1 )

		Hsz2.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs2Choices = Bfld
		self.chs2 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs2Choices, 0 )
		self.chs2.SetSelection( 0 )
		Hsz2.Add( self.chs2, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl3 = wx.StaticText( self, wx.ID_ANY, u"=", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs3Choices = Jfld
		self.chs3 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs3Choices, 0 )
		self.chs3.SetSelection( 0 )
		Hsz2.Add( self.chs3, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )


		Hsz3.Add( ( 0, 0), 1, wx.EXPAND, 5 )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancle & Return"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Ok & Apply"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz3, 1, wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.chs1.Bind(wx.EVT_CHOICE, self.tblch)
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.aply )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def tblch(self, event):
		n = self.chs1.GetSelection()
		#c = self.chs1.GetCount()
		#print(n,c)
		T1 = self.chs1.GetStringSelection()
		fld1 = self.Data[T1]
		self.chs2.SetItems([T1+'.'+f for f in fld1])
		if n  == 0:
			m = 1
		else:
			m = 0
		T2 = self.chs1.GetString(m)
		fld2 = self.Data[T2]
		self.chs3.SetItems([T2+'.'+f for f in fld2])

		event.Skip()

	def cncl( self, event ):
		self.acept = False
		q = self.GetParent()
		q.Close()

	def aply( self, event ):
		self.acept = True
		q = self.GetParent()
		q.Close()





#In the name of GOD
#Supervised Learning
#Regresion Problem
# -*- coding: utf-8 -*-
#!usr/bin/env python


class Simple_Leaner:
	def __init__(self):
		pass

	def MSE(self, y_seri, y_orgi ):
		n = len(y_orgi)
		ysum = 0
		for i in range(n):
			ysum += (y_seri[i] - y_orgi[i])**2
		return ysum / n


	def Get_Approach(self, N_seri):
		if len(N_seri) == 0:
			return -1
		N_bar = 0
		for N in N_seri:
			try:
				N_bar += float(N)
			except FloatingPointError:
				return -1

		return N_bar / len(N_seri)

	def Theta1(self, x_seri, y_seri):
		n = len(x_seri)
		hsum = 0
		hsqr = 0
		x_bar = self.Get_Approach(x_seri)
		y_bar = self.Get_Approach(y_seri)
		for i in range(n):
			hsum += (x_seri[i]-x_bar)*(y_seri[i]-y_bar)
			hsqr += (x_seri[i]-x_bar)**2
		return hsum / hsqr

	def Theta0(self, x_seri, y_seri):
		y_bar = self.Get_Approach(y_seri)
		x_bar = self.Get_Approach(x_seri)
		theta1 = self.Theta1(x_seri,y_seri)
		return y_bar - (theta1 * x_bar)



#In the name of GOD
# -*- coding: utf-8 -*-
#!usr/bin/env python

import wx
from  Config.Init import *
import Src.API.ToolBar1 as pnl

class telframe(wx.Frame):
	def __init__(self,parent):
		wx.Frame.__init__(self,parent,style=wx.FRAME_FLOAT_ON_PARENT|wx.DEFAULT_FRAME_STYLE)
		self.parent= parent

		self.Pnl = pnl.MyPanel1(self)

	def closeit(self):
		self.Close(True)

def size():
	return (-1,-1)

def main(panel=None ):
	parent =  panel.GetParent()

	frame = telframe(parent )
	frame.SetTitle(u'form')
	frame.SetSize(size())
	frame.Show()

if __name__ == '__main__':
	main()



# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc

###########################################################################
## Class MyPanel1
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 539,276 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		Hsz1 = wx.WrapSizer( wx.HORIZONTAL, 0 )

		self.txt1 = wx.StaticText( self, wx.ID_ANY, u"Toolbar Id", wx.DefaultPosition, wx.Size( 70,-1 ), 0 )
		self.txt1.Wrap( -1 )

		Hsz1.Add( self.txt1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld1 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.fld1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.txt2 = wx.StaticText( self, wx.ID_ANY, u"Tool name", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.txt2.Wrap( -1 )

		Hsz1.Add( self.txt2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld2 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.fld2, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz1, 1, wx.EXPAND, 5 )

		Hsz2 = wx.WrapSizer( wx.HORIZONTAL, 0 )

		self.txt3 = wx.StaticText( self, wx.ID_ANY, u"Toolbar Icon", wx.DefaultPosition, wx.Size( 70,-1 ), 0 )
		self.txt3.Wrap( -1 )

		Hsz2.Add( self.txt3, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.file1 = wx.FilePickerCtrl( self, wx.ID_ANY, wx.EmptyString, u"Select a file", u"*.png;*.bmp;*.jpg", wx.DefaultPosition, wx.DefaultSize, wx.FLP_DEFAULT_STYLE|wx.FLP_SMALL )
		Hsz2.Add( self.file1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.m_bitmap1 = wx.StaticBitmap( self, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz2.Add( self.m_bitmap1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.WrapSizer( wx.HORIZONTAL, 0 )

		self.txt4 = wx.StaticText( self, wx.ID_ANY, u"Short text", wx.DefaultPosition, wx.Size( 70,-1 ), 0 )
		self.txt4.Wrap( -1 )

		Hsz3.Add( self.txt4, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld3 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.fld3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.txt5 = wx.StaticText( self, wx.ID_ANY, u"Long text", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.txt5.Wrap( -1 )

		Hsz3.Add( self.txt5, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld4 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.fld4, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_CENTER_HORIZONTAL, 5 )


		Vsz1.Add( Hsz3, 1, wx.EXPAND, 5 )

		Hsz4 = wx.WrapSizer( wx.HORIZONTAL, 0 )

		self.txt6 = wx.StaticText( self, wx.ID_ANY, u"Program", wx.DefaultPosition, wx.Size( 70,-1 ), 0 )
		self.txt6.Wrap( -1 )

		Hsz4.Add( self.txt6, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.file2 = wx.FilePickerCtrl( self, wx.ID_ANY, wx.EmptyString, u"Select a file", u"*.*;*.py", wx.DefaultPosition, wx.DefaultSize, wx.FLP_DEFAULT_STYLE|wx.FLP_SMALL )
		Hsz4.Add( self.file2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld5 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.fld5, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz4, 1, wx.EXPAND, 5 )

		Hsz5 = wx.WrapSizer( wx.HORIZONTAL, wx.WRAPSIZER_DEFAULT_FLAGS )

		self.Box1 = wx.CheckBox( self, wx.ID_ANY, u"Disable", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz5.Add( self.Box1, 0, wx.ALL, 5 )

		self.Box2 = wx.CheckBox( self, wx.ID_ANY, u"Hiden", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz5.Add( self.Box2, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz5, 1, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		Hsz6 = wx.WrapSizer( wx.HORIZONTAL, 0 )


		Hsz6.Add( ( 0, 0), 1, wx.EXPAND, 5 )

		self.btn1 = wx.Button( self, wx.ID_ANY, u"Cancle", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz6.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, u"Add", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz6.Add( self.btn2, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz6, 0, wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.file1.Bind( wx.EVT_FILEPICKER_CHANGED, self.icnfil )
		self.file2.Bind( wx.EVT_FILEPICKER_CHANGED, self.prgfil )
		self.Box1.Bind( wx.EVT_CHECKBOX, self.disbl )
		self.Box2.Bind( wx.EVT_CHECKBOX, self.hidn )
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.Doit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def icnfil( self, event ):
		event.Skip()

	def prgfil( self, event ):
		event.Skip()

	def disbl( self, event ):
		event.Skip()

	def hidn( self, event ):
		event.Skip()

	def cncl( self, event ):
		q = self.GetParent()
		q.Close()

	def Doit( self, event ):
		event.Skip()




#In The name of God
#!/usr/bin/env python
# -*- codnig: utf-8 -*-
import sqlite3

from . import wxsq as sq
from . import  srcsql as ss
from Config.Init import *

class Get:
    def __init__(self, DBF, Data, file):
        self.DBF = DBF
        self.Data = Data

        if file != '':
            sqlfile = DATABASE_PATH + 'sqls' + SLASH + file
            #sqlfile = Src_dbf + 'sqls' + SLASH + file
            self.SQLtxt = self.openSql(sqlfile)

    def openSql(self, sqlfile):
        with open(sqlfile) as f:
            alltxt = f.readlines()
        #print(alltxt)
        return alltxt[0]

    def GetFromDbf(self):
        return sq.wxsqltxt(self.DBF, self.SQLtxt)

    def GetFromDbfWithData(self):
        return sq.wxsqltxt(self.DBF, self.SQLtxt + self.Data )

    def GetFromString(self, string):
        return sq.wxsqltxt(self.DBF, string)

    def __del__(self):
        pass

    def __hash__(self):
        pass



class Post:
    def __init__(self, DBF, Tabel, Field, Data):
        self.DBF = DBF
        self.Tabel = Tabel
        #self.Field = Field
        #self.Data = Data

    def Addrecord(self,Field,Data):
        return sq.wxsqins(self.DBF, self.Tabel, Field, Data)

    def Addrecord2(self,Field,Data):
        return sq.wxsqins2(self.DBF, self.Tabel, Field, Data)

    def Updaterecord(self,Field,Data):
        return sq.wxsqlup(self.DBF, self.Tabel, Field, Data)

    def Updaterecord2(self,Field,Data):
        return sq.wxsqlup2(self.DBF, self.Tabel, Field, Data)

    def Deleterecord(self,Data):
        return sq.wxsqdel(self.DBF, self.Tabel, Data)

    def DeleteAllrecord(self,Field):
        return sq.wxsqdall(self.DBF, Field)


    def __del__(self):
        pass

    def __hash__(self):
        pass

class Get2:
    def __init__(self, DBF, Data, file):
        self.DBF = DBF
        self.Data = Data
        self.file = file

        if file != '':
            sqlfile = Src_dbf + 'sqls' + SLASH + file
            #sqlfile = Src_dbf + 'sqls' + SLASH + file
            self.SQLtxt = self.openSql(sqlfile)

    def openSql(self, sqlfile):
        with open(sqlfile) as f:
            alltxt = f.read()
        #print(alltxt)
        return alltxt[0]

    def GetFromDbf(self):
        return ss.wxsqltxt(self.DBF, self.SQLtxt)

    def GetFromDbfWithData(self):
        return ss.wxsqltxt(self.DBF, self.SQLtxt + self.Data )

    def GetFromString(self, string):
        return ss.wxsqltxt(self.DBF, string)

    def GetFromString2(self, string, fields):
        cur = ss.SFDB(self.DBF)
        return cur.cursor.execute(string,fields)

    def GetCommandStr(self, database , string):
        cur = ss.MyDB_Path(database)
        cur.execute(string)

    def __del__(self):
        pass

    def __hash__(self):
        pass


class Post2:
    def __init__(self, DBF, Tabel, Field, Data):
        self.DBF = DBF
        self.Tabel = Tabel
        #self.Field = Field
        #self.Data = Data

    def Addrecord(self,Field,Data):
        return ss.wxsqins(self.DBF, self.Tabel, Field, Data)

    def Addrecord2(self,Field,Data):
        return ss.wxsqins2(self.DBF, self.Tabel, Field, Data)

    def Addrecord3(self,Field,Data):
        return ss.wxsqins3(self.DBF, self.Tabel, Field, Data)

    def Updaterecord(self,Field,Data):
        return ss.wxsqlup(self.DBF, self.Tabel, Field, Data)

    def Updaterecord2(self,Field,Data):
        return ss.wxsqlup2(self.DBF, self.Tabel, Field, Data)

    def Deleterecord(self,Data):
        return ss.wxsqdel(self.DBF, self.Tabel, Data)

    def DeleteAllrecord(self,Field):
        return ss.wxsqdall(self.DBF, Field)


    def __del__(self):
        pass

    def __hash__(self):
        pass


#In the name of GOD
#Import the need file for all prg

import os
import sys
import glob
import time

import importlib
import importlib.util

import wx
import wx.adv
import wx.aui
import wx.dataview

import AI
import AI.ML

import Config.Init

import Database.MenuSet2
import Database.wxsq

import DCC1

import GUI
import GUI.window2
import GUI.Start
import GUI.MainMenu2
import GUI.MainTool
import GUI.proman
import GUI.BG2



# In the name of God
# Cearte Toolbar in Frame window
#! /usr/bin/env python
# -*- coding: utf-8 -*-

import Database.MenuSet2 as MS
from Allimp import os,sys,wx
from  Config.Init import *



class ToolData(object):
    def __init__(self):
        self.MySql = MS.GetData(u'Menu2.db', u'')
        self.ToSql = MS.SetData(u'', u'',u'')
        self.mTBarLst = {}

    def ToolBarData(self):
        self.mTBar = []
        for row in self.MySql.GetTB():
            self.mTBar.append(row)
        #return self.mTBar
    def ToolBarList(self):
        self.ToolBarData()
        for TB in self.mTBar:
            if TB[0]//100 not in self.mTBarLst:
                self.mTBarLst[TB[0]//100] = [TB]
            else:
                self.mTBarLst[TB[0]//100].append(TB)
        return self.mTBarLst


class MyToolbar(wx.ToolBar):
    data = []          #wx.TB_NODIVIDER | wx.NO_BORDER | wx.TB_FLAT |
    def __init__(self,parent,style=  wx.TB_HORIZONTAL | wx.NO_BORDER | wx.TB_FLAT|wx.TB_TEXT):
        wx.ToolBar.__init__(self,parent,style=style)
        self.mytb = []


    def CreatTool(self,tbData):
        #print(tbData)
        for grp in tbData:
            for tb in tbData[grp] :
                if str(tb[1]) == '' or tb[1] == None:
                    #self.mytb.append( self.AddTool(int(tb[0]),wx.EmptyString,wx.NullBitmap,wx.NullBitmap,
                    #                           wx.ITEM_SEPARATOR,wx.EmptyString,wx.EmptyString, None) )
                    self.AddSeparator()
                elif tb[5] == 'C':
                    self.mytb.append(
                        self.AddTool(int(tb[0]), str(tb[1]), wx.Bitmap(ICONS_TOOL + tb[2], wx.BITMAP_TYPE_ANY),
                                     wx.NullBitmap, wx.ITEM_CHECK, str(tb[3]), wx.EmptyString, None)
                    )
                elif tb[5] == 'R':
                    self.mytb.append(
                        self.AddTool(int(tb[0]), str(tb[1]), wx.Bitmap(ICONS_TOOL + tb[2], wx.BITMAP_TYPE_ANY),
                                     wx.NullBitmap, wx.ITEM_RADIO, str(tb[3]), wx.EmptyString, None)
                    )
                else:
                    self.mytb.append(
                        self.AddTool(int(tb[0]), str(tb[1]),wx.Bitmap(ICONS_TOOL+tb[2], wx.BITMAP_TYPE_ANY),
                                     wx.NullBitmap, wx.ITEM_NORMAL, str(tb[3]), wx.EmptyString, None)
                    )

            self.AddSeparator()
        self.Realize()
        return self

    def GetToolid(self, id):
        return self.FindById(id)

class MyAuiToolbar(wx.aui.AuiToolBar):
    data = []
    def __init__(self, parent , style = wx.aui.AUI_TB_DEFAULT_STYLE|wx.aui.AUI_TB_GRIPPER|wx.aui.AUI_TB_PLAIN_BACKGROUND|wx.aui.AUI_TB_TEXT):
        wx.aui.AuiToolBar.__init__(self,parent,style = style )
        self.mytb = []
        self.mytp = {}
        #self.CreatTool(self.data)

    def CreatTool(self,tbData):
        for tb in tbData :
            if str(tb[1]) == '' or tb[1] == None:
                self.AddSeparator()
            else:
                self.mytb.append( self.AddTool(int(tb[0]), str(tb[1]),wx.Bitmap(ICONS_TOOL+tb[2], wx.BITMAP_TYPE_ANY),
                                               wx.NullBitmap, wx.ITEM_NORMAL, str(tb[3]), wx.EmptyString, None) )
        self.Realize()
        return self




# In the name of God
# -*- coding: utf-8 -*-
# Windows Back Ground
# ! /usr/bin/env python

import wx
import wx.aui as wxaui
from Config.Init import *

import GUI.proman as pro

_ = wx.GetTranslation


class BGPanel(wx.Panel):
	def __init__(self, parent, BGfile):
		wx.Panel.__init__(self, parent=parent, id=wx.ID_ANY, pos=wx.DefaultPosition, size=wx.DefaultSize,
		                  style=wx.TAB_TRAVERSAL)

		# bSizer2 = wx.BoxSizer( wx.VERTICAL )

		self.BGfile = BGfile

		self.SetBackgroundStyle(wx.BG_STYLE_ERASE)
		self.Bind(wx.EVT_ERASE_BACKGROUND, self.OnEraseBackground)

		self.Bind(wxaui.EVT_AUI_RENDER, self.OnEraseBackground)

	def __del__(self):
		pass

	# Virtual event handlers, overide them in your derived class

	def m_bitmap4OnContextMenu(self, event):
		self.PopupMenu(self.m1)



	def OnEraseBackground(self, evt):
		# yanked from ColourDB.py
		# print(evt)
		dc = evt.GetDC()
		if not dc:
			dc = wx.ClientDC(self)
			rect = self.GetUpdateRegion().GetBox()
			# dc.SetClippingRect(rect)
			dc.SetClippingRegion(rect)
		dc.Clear()
		# bmp = wx.Bitmap(PICS_PATH+self.BGfile)
		bmp = wx.Bitmap(self.BGfile)
		img = bmp.ConvertToImage()
		img2 = img.Scale(wx.GetDisplaySize()[0], wx.GetDisplaySize()[1])
		bmp2 = img2.ConvertToBitmap()

		dc.DrawBitmap(bmp2, 0, 0)

	def ChangeBackGround(self):
		dc = wx.ClientDC(self)
		rect = self.GetUpdateRegion().GetBox()
		dc.SetClippingRegion(rect)
		dc.Clear()
		bmp = wx.Bitmap(self.BGfile)
		img = bmp.ConvertToImage()
		img2 = img.Scale(wx.GetDisplaySize()[0], wx.GetDisplaySize()[1])
		bmp2 = img2.ConvertToBitmap()
		dc.DrawBitmap(bmp2, 0, 0)
		self.Refresh()



#In the name of GOD
from setuptools import setup, find_packages

long_desc = open("c:\\MPT5.1.0.0\\README.md").read()
setup(
    name='MPT5.0.3.1',
    version='0.3.1',
    description = "MPT5 Test ML Environment",
    long_description=long_desc,
    long_description_content_type='text/markdown',
    license='GNU',
    author="Pooya Ghiami",
    author_email='pooyagheyami@gmail.com',
    packages=find_packages(
        where='src',
        include=['*'],
        ),
    package_dir={'': 'src'},
    package_data={
        "MPT5": ["*.txt"],
        "MPT5.Database": ["*.db"],
        "MPT5.Config":["*.ini"],
        "MPT5.Database.sqls":["*.sql"],
        "MPT5.locale.en":["*.mo","*.po"],
        "MPT5.Fount":["*.sql","*.ini","*.txt"]
        },
    include_package_data=True,
    scripts=['scripts/make.py'],
    url='https://github.com/Srcfount/MPT5/',
    keywords='MACHINELEARNING GUI SQL',
    install_requires=[
          'wxPython',
      ],
##    entry_points={
##        'console_scripts': [
##            'make = MPT5:make cmd1 cmd2'
##
##            ]
##        },
    #script_name='make cmd1 cmd2',
    #script_args=['cmd1','cmd2']
    

)
##
##import setuptools
##
##long_desc = open("README.md").read()
##required = ['wxpython'] # Comma seperated dependent libraries name
##
##setuptools.setup(
##    name="MPT5.1.0",
##    version="1.0.0", # eg:1.0.0
##    author="Pooya Ghiami",
##    author_email="pooyagheyami@gmail.com",
##    license="GNU",
##    description="MPT5 Test ML Environment",
##    long_description=long_desc,
##    #long_description_content_type="text/markdown",
##    url="https://github.com/Srcfount/MPT5/",
##    #packages = ['c:\\MPT5.1.0.0'],#setuptools.find_packages('src'), #['MPT5.1.0'],
##    # project_urls is optional
##    #project_urls={
##    #    "Bug Tracker": "<BUG_TRACKER_URL>",
##    #},
##    keywords="MACHINELEARNING GUI SQL",
##    install_requires=required,
##    packages=setuptools.find_packages(where="src"),
##    python_requires=">=3.6",
##)


##name string
##
##version string
##
##description string
##
##long_description string
##
##long_description_content_type string
##
##author string
##
##author_email string
##
##maintainer string
##
##maintainer_email string
##
##url string
##
##download_url string
##
##packages list
##
##py_modules list
##
##scripts list
##
##ext_package string
##
##ext_modules list
##
##classifiers list
##
##distclass Distribution subclass
##
##script_name string
##
##script_args list
##
##options dictionary
##
##license string
##
##license_file string deprecated
##
##license_files list
##
##keywords string or list
##
##platforms list
##
##cmdclass dictionary
##
##data_files list deprecated
##
##package_dir dictionary
##
##requires string or list deprecated
##
##obsoletes list deprecated
##
##provides list



#In the name of GOD
#DB Generate Add line for Connect DB to Program
# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc

###########################################################################
## Class MyPanel
###########################################################################

class TxtPanel ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,300 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.Txt = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_DONTWRAP|wx.TE_LEFT|wx.TE_MULTILINE )
		Vsz1.Add( self.Txt, 1, wx.ALL|wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.Txt.Bind(wx.EVT_RIGHT_DOWN, self.domnu)

	def __del__( self ):
		pass

	# Virtual event handlers, overide them in your derived class
	def domnu(self, event):
		m1 = wx.Menu()
		itm1  = wx.MenuItem(m1,wx.ID_ANY,u'Copy Select',wx.EmptyString, wx.ITEM_NORMAL )
		m1.Append(itm1)
		m1.AppendSeparator()
		itm2 = wx.MenuItem(m1, wx.ID_ANY, u'Select All', wx.EmptyString, wx.ITEM_NORMAL)
		m1.Append(itm2)
		m1.AppendSeparator()
		itm3 = wx.MenuItem(m1, wx.ID_ANY, u'Return ', wx.EmptyString, wx.ITEM_NORMAL)
		m1.Append(itm3)
		self.Bind(wx.EVT_MENU, self.doitm, id=itm1.GetId())
		self.Bind(wx.EVT_MENU, self.doitm, id=itm2.GetId())
		self.Bind(wx.EVT_MENU, self.doitm, id=itm3.GetId())
		self.PopupMenu(m1)
		m1.Destroy()

	def doitm(self, event):
		mnu = event.GetEventObject()
		#print(mnu.GetLabelText(event.GetId()))
		lbl = mnu.GetLabelText(event.GetId())
		if lbl == u'Copy Select':
			myslct = self.Txt.GetStringSelection()
			clipit = wx.TextDataObject()
			clipit.SetText(myslct)
			if wx.TheClipboard.Open():
				wx.TheClipboard.SetData(clipit)
				wx.TheClipboard.Flush()

			#print(myslct)
		elif lbl == u'Select All':
			self.Txt.SelectAll()

		elif lbl == u'Return ':
			q = self.GetParent()
			q.Close()
		else:
			print(u'error')







###########################################################################
## Class MyMenuBar2
###########################################################################

class MyMenuBar2 ( wx.MenuBar ):

	def __init__( self , whatmnu=u''):
		wx.MenuBar.__init__ ( self, style = 0 )

		self.mnu2 = wx.Menu()
		if whatmnu == u'prg':
			self.itm1 = wx.MenuItem( self.mnu2, wx.ID_ANY, u"Copy Select", wx.EmptyString, wx.ITEM_NORMAL )
			self.mnu2.Append( self.itm1 )
			self.Bind(wx.EVT_MENU, self.cpyslct, id=self.itm1.GetId())

		elif whatmnu == u'sql':
			self.itm2 = wx.MenuItem( self.mnu2, wx.ID_ANY, u"to SQL file", wx.EmptyString, wx.ITEM_NORMAL )
			self.mnu2.Append( self.itm2 )
			self.Bind(wx.EVT_MENU, self.tosql, id=self.itm2.GetId())
		else:
			pass

		self.mnu2.AppendSeparator()

		self.itm3 = wx.MenuItem( self.mnu2, wx.ID_ANY, u"Return", wx.EmptyString, wx.ITEM_NORMAL )
		self.mnu2.Append( self.itm3 )

		self.Append( self.mnu2, u"Tools" )


		# Connect Events
		#self.Bind( wx.EVT_MENU, self.cpyslct, id = self.itm1.GetId() )
		#self.Bind( wx.EVT_MENU, self.tosql, id = self.itm2.GetId() )
		self.Bind( wx.EVT_MENU, self.rtrn, id = self.itm3.GetId() )
		self.Bind( wx.EVT_UPDATE_UI, self.updat, id = self.itm3.GetId() )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def cpyslct( self, event ):
		event.Skip()

	def tosql( self, event ):
		event.Skip()

	def rtrn( self, event ):
		q = self.GetParent()
		q.Close()

	def updat( self, event ):
		event.Skip()



#In the name of GOD
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import shutil
import sqlite3
import update
import requests

main_direct = ['AI', 'Config', 'Database', 'DCC1', 'GUI', 'GUI\\Temp', 'GUI\\API', 'GUI\\AuiPanel', 'GUI\\Main',
               #'Locale', 'Locale\\en', 'Locale\\fa', 'Locale\\fr', 'Locale\\gr', 'Locale\\sp', 'Locale\\tr',
               'Logs', 'Res', 'Res\\Fonts', 'Res\\Icons', 'Res\\Icons\\Menu', 'Res\\Icons\\Toolbar',
               'Res\\Icons\\16x16', 'Res\\Icons\\32x32', 'Res\\Images', 'Res\\Pics', 'Res\\Splash',
               'Src', 'Src\\API', 'Src\\AUI', 'Src\\DBF', 'Src\\DBF\\sqls', 'Src\\GUI', 'Src\\MLA', 'Src\\MLP', 'Src\\PRG',
               'Temps', 'Utility', 'Utility\\Fount', 'Utility\\Fount\\GUI', 'Utility\\Fount\\MLA', 'Utility\\Fount\\MLP',
               'Utility\\Fount\\AUI', 'Utility\\Fount\\PRG', 'Utility\\Fount\\API', 'Utility\\UpdateApp',
               'Utility\\Free','Utility\\Account','Utility\\Uploads','Utility\\Downloads'
               ]

local_direct = ['Locale', 'Locale\\en', 'Locale\\fa', 'Locale\\fr', 'Locale\\gr', 'Locale\\sp', 'Locale\\tr']

main_file = {
	'AI': ['OpnSrc.py', 'Generats.py', 'DBgen.py', 'Analiz.py'],
    'Config': ['Init.py'],
    'Database': ['wxsq.py', 'PostGet2.py', 'PostGet.py', 'MenuSet2.py','srcsql.py','dbinterface.py'],
	'DCC1': ['Proper2.py', 'MenuDev2.py', 'DBDev2.py', 'ToolBar2.py', 'ProgDev2.py', 'MLDev2.py', 'ListPro2.py', 'AuiPan2.py'],
	'GUI': ['window2.py', 'Start.py', 'proman.py', 'MainTool.py', 'MainMenu2.py', 'BG2.py'],
	'GUI\\Temp': ['untitle.py', 'Demo.py', 'Muntitle.py'],
	'GUI\\API': ['SamPnl.py'],
	'GUI\\AuiPanel': ['tempane.py', 'PAui.py'],
	'GUI\\Main': ['TPv1.py', 'TBv1.py', 'PPv1.py', 'PGv1.py', 'PAv1.py', 'MLv1.py', 'MDv1.py', 'DBv1.py'],
	'Res': ['Allicons.py'],
}

creat_file = {
	'Config': ['MLmethod.ini', 'option.ini', 'system1.ini'],
	'Database': ['Menu2.db'],
	'..': ['Mainpro.py','update.py','requirements.txt','Allimp.py']
}

def create_this(file,source,target):
	if file == 'Menu2.db':
		print('.',end='')
		connection = sqlite3.connect(target+file)
		cursor = connection.cursor()
		with open(source+'Createmenu.sql', 'r') as f:
			cursor.executescript(f.read())
		connection.commit()
		connection.close()
	else:
		print('.', end='')
		shutil.copyfile(source + file, target + file)

def generate_path(mydir):
	if not os.path.isdir(mydir):
		print('.', end='')
		os.mkdir(mydir)

	os.chdir(mydir)

	for dir in main_direct:
		if not os.path.isdir(dir):
			os.mkdir(dir)
			print('.', end='')
			if not os.path.isfile(mydir+dir+'\\'+'__init__.py'):
				with open(mydir +dir+'\\'+'__init__.py','w') as f:
					f.write('')
					print('.', end='')

	for dir in local_direct:
		if not os.path.isdir(dir):
			os.mkdir(dir)
			print('.', end='')

	for dir in main_file:
		for fil in main_file[dir]:
			if not os.path.isfile(mydir+dir+'\\'+fil):
				with open(mydir+dir+'\\'+fil,'w') as f:
					f.write('')
					print('.', end='')

	for Dir in creat_file:
	   for file in creat_file[Dir]:
		   if Dir != '..':
			   if not os.path.isfile(mydir+Dir+'\\'+file):
				   with open(mydir+Dir+'\\'+file,'w') as f:
					   f.write('')
					   print('.', end='')
		   else:
			   with open(mydir+ file, 'w') as f:
				   f.write('')
				   print('.', end='')

	for Dir in creat_file:
		for file in creat_file[Dir]:
			if Dir != '..':
				if os.stat(mydir+Dir+'\\'+file).st_size == 0:
					create_this(file,'c:\\MPT5\\Fount\\',mydir+Dir+'\\')
			else:
				if os.stat(mydir+file).st_size == 0:
					create_this(file,'c:\\MPT5\\Fount\\',mydir)


def main(argv):
	#print(argv)
	arg_help = """syntax is :{0} <option> <directory> \n 
	    Options: 
	        Create = Make a new empty project 
	        Update = Update my program platform \n
	    example: 
	        {0} Create c:\Temp5\myProject\ 
	        {0} Update c:\Temp5\myProject\  \n """.format(argv[0])

	if len(argv) < 3:
		print(arg_help)
		exit()
	else:
		if 'Create' in argv:
			if argv[2] != '' or argv[2] != None:
				mydir = argv[2]
			else:
				print(" Please set Path to create a project")
				exit()
		elif 'Update' in argv:
			if argv[2] != '' or argv[2] != None:
				mydir = argv[2]
			else:
				print(" Please set Path to create a project")
				exit()

		#print(argv[1])

	if not os.path.isdir("c:\\Temp5"):
		os.mkdir("c:\\Temp5\\")

	if not os.path.isfile("c:\\Temp5\\MPT5.zip"):
		print('Please wait...')
		url = "https://github.com/Srcfount/MPT5/archive/refs/heads/master.zip"
		filobj = requests.get(url)
		with open("c:\\Temp5\\MPT5.zip",'wb') as f:
			f.write(filobj.content)
		shutil.unpack_archive('c:\\Temp5\\MPT5.zip','c:\\Temp5','zip')
		#print(os.getcwd())
		os.chdir('c:\\Temp5\\')
		if not os.path.isdir('c:\\Temp5\\MPT5'):
			shutil.move('MPT5-master','MPT5')

	if argv[1] == 'Create':
		if mydir[-1] != '\\':
			print(arg_help)
			print('Write a correct directory format')
			exit()
		elif mydir == '':
			print(arg_help)
			print('Exit setup. you not entered correct syntax')
			exit()
		else:
			generate_path(mydir)
			update.main()
	elif argv[1] == 'Update':
		if mydir[-1] != '\\':
			print(arg_help)
			print('Write a correct directory format')
			exit()
		elif mydir == '':
			print(arg_help)
			print('Exit setup. you not entered correct syntax')
			exit()
		else:
			update.main()

	os.chdir(mydir)
	print("Please change path to %s and execute this command: \n >> python -m Mainpro \n or: \n >> python mainpro.py " %mydir)
	exit()


if __name__ == '__main__':
	main(sys.argv)


#In the name of God
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import shutil


main_direct = ['AI', 'Config', 'Database', 'DCC1', 'GUI', 'GUI\\Temp', 'GUI\\API', 'GUI\\AuiPanel', 'GUI\\Main', 'Res']

main_file = {
	'AI': ['OpnSrc.py', 'Generats.py', 'DBgen.py', 'Analiz.py'],
    'Config': ['Init.py'],
    'Database': ['wxsq.py', 'PostGet2.py', 'PostGet.py', 'MenuSet2.py','srcsql.py','dbinterface.py'],
	'DCC1': ['Proper2.py', 'MenuDev2.py', 'DBDev2.py', 'ToolBar2.py', 'ProgDev2.py', 'MLDev2.py', 'ListPro2.py', 'AuiPan2.py'],
	'GUI': ['window2.py', 'Start.py', 'proman.py', 'MainTool.py', 'MainMenu2.py', 'BG2.py'],
	'GUI\\Temp': ['untitle.py', 'Demo.py', 'Muntitle.py'],
	'GUI\\API': ['SamPnl.py'],
	'GUI\\AuiPanel': ['tempane.py', 'PAui.py'],
	'GUI\\Main': ['TPv1.py', 'TBv1.py', 'PPv1.py', 'PGv1.py', 'PAv1.py', 'MLv1.py', 'MDv1.py', 'DBv1.py'],
	'Res': ['Allicons.py'],
}

def main():
	source_dirct = 'c:\\MPT5\\'
	target_dirct = os.getcwd()+'\\'
	for dirct in main_direct:
		for update_file in main_file[dirct]:
			shutil.copyfile(source_dirct+dirct+'\\'+update_file,target_dirct+dirct+'\\'+update_file)
			print('.', end='')

	print(u'successful Update')


if __name__ == '__main__':
	main()


#In The name of God
#!/usr/bin/env python
# -*- codnig: utf-8 -*-

from . import wxsq as sq


class GetData:
    def __init__(self, DBF, sends):
        self.DBF = DBF
        #self.sends = sends

    def ShowItem(self, ibar=1, ext=''):
        return sq.wxsqltxt(self.DBF, """select distinct mitem.extid, mitem.itemid,mitem.mbarid,mitem.itemname,handler.prgname,extended.acclvlid, mitem.itemtyp
                                        from mitem
                                        left join handler on handler.handlerid = mitem.handlerid
                                        left join extended on extended.extid = mitem.extid
                                        where mitem.mbarid = %d
                                        %s
                                        """ % (ibar,ext))

    def gItem(self, mbar=1, ext=''):
        return sq.wxsqltxt(self.DBF, """select mitem.itemname,mitem.itemid
                                        from mitem
                                        where mitem.mbarid = %d
                                         %s """ % (mbar, ext) )
    def gBarN(self, mbar=1):
        return sq.wxsqsnd(self.DBF,u'menubar',u'mbarname',u'mbarid',mbar)

    def gBarId(self, mbnm=''):
        return sq.wxsqsnd(self.DBF,u'menubar',u'mbarid',u'mbarname',mbnm)


    def AmenuBar(self, Access=u'FFFF',ext=''):
        return sq.wxsqltxt(self.DBF, """ SELECT distinct *
                                         FROM menubar,access
                                         where menubar.acclvlid = access.acclvlid
                                         and access.acclvl = '%s' and access.userid = 1
                                         %s order by menubar.mbarid""" % (Access,ext)
                           )
    def AmenuBar2(self, Access=u'FFFF',ext='',userid = 1):
        return sq.wxsqltxt(self.DBF, """ SELECT distinct *
                                         FROM menubar,access
                                         where menubar.acclvlid = access.acclvlid
                                         and access.acclvl = '%s' and access.userid = %d
                                         %s order by menubar.mbarid""" % (Access,userid,ext)
                           )
    def AmenuItm(self, barid=101, ext=''):
        return sq.wxsqltxt(self.DBF, """SELECT DISTINCT mitem.itemid,mitem.itemname,extended.status,extended.shortcut,extended.icon,mitem.itemtyp
                     FROM mitem
                     left join extended on mitem.extid = extended.extid
                     WHERE mitem.mbarid = %d
                     %s  """ % (barid,ext) )  #ORDER BY mitem.itemid

    def AmenuItm2(self, barid=101, ext='', usrid=1):
        return sq.wxsqltxt(self.DBF, """ SELECT DISTINCT mitem.itemid,mitem.itemname,extended.status,extended.shortcut,extended.icon,mitem.itemtyp,access.acclvl,access.disenable
                     FROM mitem
                     left join extended on mitem.extid = extended.extid
					 left join access on extended.acclvlid = access.acclvlid and access.userid = %d
                     WHERE mitem.mbarid = %d
                     %s """  % (usrid, barid,ext) )
    def getmItem(self, itmid=0):
        return sq.wxsqltxt(self.DBF, """ SELECT DISTINCT *
                     FROM mitem
                     left join extended on mitem.extid = extended.extid
                     left join access on extended.acclvlid = access.acclvlid
                     left join handler on mitem.handlerid = handler.handlerid
                     WHERE mitem.itemid = %d """ % itmid)

    def DirBar(self):
        return sq.wxsqltxt(self.DBF, """SELECT menubar.mbardir
                                        FROM menubar
                                        """)
    def AllBar(self,ext=''):
        return sq.wxsqltxt(self.DBF,"""SELECT * FROM menubar %s"""%ext)

    def AllSub(self, ext=''):
        return sq.wxsqltxt(self.DBF,"""SELECT * FROM mitem %s"""%ext)


    def MyProg(self,itemid=''):
        return sq.wxsqltxt(self.DBF,"""SELECT distinct mitem.handlerid, handler.prgname
            FROM mitem join handler on mitem.handlerid = handler.handlerid
            WHERE mitem.itemid = %s  """ %itemid)


    # def MnuDir(self,itemid=''):
    #     return  sq.wxsqltxt(self.DBF, """SELECT menubar.mbardir
    #           FROM mitem  JOIN handler  ON mitem.handlerid = handler.handlerid
	# 		  JOIN menubar ON handler.prgdir = menubar.mbarid
    #           WHERE mitem.itemid =  %s  """ %itemid)

    def MnuDir2(self,itemid=''):
        return sq.wxsqltxt(self.DBF, """SELECT Guidir.Dir
              FROM mitem  JOIN handler  ON mitem.handlerid = handler.handlerid
			  JOIN menubar ON menubar.mbarid = mitem.mbarid
			  JOIN Guidir ON menubar.mbardir = Guidir.prgdir
			  WHERE mitem.itemid = %s  """ %itemid)

    def SubDir(self,itemsub=''):
        return sq.wxsqltxt(self.DBF, """SELECT handler.prgdir
              FROM mitem  JOIN handler
              ON mitem.handlerid = handler.handlerid
              WHERE mitem.itemid = %s  """ %itemsub)

    def SubDir2(self, itemsub=''):
        return sq.wxsqltxt(self.DBF,"""SELECT Guidir.Dir
              FROM mitem  JOIN handler  ON mitem.handlerid = handler.handlerid
              JOIN Guidir ON Guidir.prgdir = handler.prgdir
              WHERE mitem.itemid = %s  """ %itemsub)

    def AllGuiDir(self, ext=''):
        return sq.wxsqltxt(self.DBF, """ SELECT * FROM Guidir %s""" %ext)

    def GetDirCod(self, idir=''):
        return sq.wxsqsnd(self.DBF,"Guidir", "hdddir", "prgdir", idir)

    def GetImpCod(self, icod=''):
        return sq.wxsqsnd(self.DBF,"Guidir", "Dir", "prgdir", icod)

    def GetDirCod2(self, idir=''):
        return sq.wxsqsnd(self.DBF,"Guidir", "prgdir", "hdddir", idir)

    def DoHdnl(self):
        return sq.wxsqltxt(self.DBF,"""select handler.prgname
          from handler join mitem on mitem.handlerid = handler.handlerid
          WHERE  mitem.handlerid  notnull """)
    def RunHdnl(self, hndid = ''):
        return sq.wxsqltxt(self.DBF, """ select Guidir.Dir, handler.prgname
        from Guidir, handler
        where Guidir.prgdir = handler.prgdir
        and handler.handlerid = %s """ % hndid )

    def AllHndl(self, ext=''):
        return sq.wxsqltxt(self.DBF,""" select distinct * from handler %s """ % ext)

    def GetTB(self):
        return sq.wxsqltxt(self.DBF,"""select toolbar.toolid,toolbar.toolname,toolbar.toolicon,toolbar.shrttxt,handler.prgname,toolbar.tooltype
                                       from toolbar left join handler
                                       on toolbar.handlerid = handler.handlerid
                                        order by toolbar.toolid """)

    def GetAllTB(self, ext=''):
        return sq.wxsqltxt(self.DBF,""" select DISTINCT * from toolbar %s order  by toolbar.toolid""" % ext)

    def MyTogr(self,itolid=''):
        return sq.wxsqltxt(self.DBF,"""SELECT distinct toolbar.handlerid, handler.prgname
            FROM toolbar join handler on toolbar.handlerid = handler.handlerid
            WHERE toolbar.toolid = %s  """ %itolid)

    def TolDir(self,itolid=''):
        return sq.wxsqltxt(self.DBF, """ select distinct menubar.mbardir , mitem.handlerid
            from menubar, toolbar  inner join mitem on mitem.handlerid = toolbar.handlerid
            where menubar.mbarid = mitem.mbarid
            and toolbar.toolid =  %s  """ % itolid)
    def TolDir2(self,itolid=''):
        return sq.wxsqltxt(self.DBF, """select distinct Guidir.Dir , toolbar.handlerid
            from  toolbar  
			join handler on toolbar.handlerid = handler.handlerid
			join Guidir on handler.prgdir = Guidir.prgdir
            and toolbar.toolid = %s   """ % itolid)
    def Acclvl(self,accid=''):
        return sq.wxsqltxt(self.DBF, """ select * from access where access.acclvlid = '%s' """ % accid)

    def gBarItm(self,mbar=''):
        return  sq.wxsqltxt(self.DBF,""" select distinct mitem.mbarid , mitem.itemid , mitem.extid , extended.acclvlid
                                     from mitem,extended 
                                     where mitem.mbarid = %s""" % mbar)
    def gSubItm(self,mitm=''):
        return sq.wxsqltxt(self.DBF,""" select distinct mitem.mbarid , mitem.itemid , mitem.extid , extended.acclvlid 
                                    from mitem left Join extended on mitem.extid = extended.extid 
                                    where mitem.mbarid/10 = %d or mitem.mbarid / 100 = %d """ %(mitm,mitm))
    def getHndlr(self, prgnam = u'', ext=''):
        return sq.wxsqltxt(self.DBF, """ select handler.handlerid, handler.prgdir 
                                    from handler     where handler.prgname = '%s'  %s """ %( prgnam,ext ) )

    def getHndid(self, mid=''):
        return sq.wxsqltxt(self.DBF, """ select handler.handlerid from handler where handler.prgdir = '%s' 
         order by handlerid """ % mid )

    def gethddir(self, dirct= u''):
        return sq.wxsqsnd(self.DBF,u'menubar',u'mbarid',u'mbardir',dirct)

    def AllPanes(self):
        return sq.wxsqltxt(self.DBF,""" select * from pans join panifo on pans.paninfoid = panifo.paninfoid
         order by pans.panid""")

    def ListPanes(self):
        return sq.wxsqltxt(self.DBF," select pans.panname from pans order by pans.panid")

    def ProPane(self, ext=''):
        return sq.wxsqltxt(self.DBF,""" select pans.panid, pans.panname, pans.handlerid, handler.prgname , handler.prgdir
                                        from pans, handler  where pans.handlerid = handler.handlerid  %s""" %ext)

    def getPane(self, panid='', ext=''):
        return sq.wxsqltxt(self.DBF," select * from pans where pans.panid = %d  %s" %(int(panid),ext))

    def MLPansFils(self, ext=u''):
        return sq.wxsqltxt(self.DBF, ' select * from MLPane %s ' %ext )

    def MLAlgoFils(self, ext=u''):
        return sq.wxsqltxt(self.DBF, ' select * from MLAlgo %s ' %ext )

    def AllML(self, ext=u''):
        return sq.wxsqltxt(self.DBF, ' select * from MLinfo %s ' %ext )

    def MLPansgetAl(self, mlcod=u''):
        return sq.wxsqltxt(self.DBF, " select * from MLAlgo where MLAlgo.MLcod = '%s' " %mlcod )

    def MLPanid(self, Apnm=u''):
        return sq.wxsqsnd(self.DBF,u'MLinfo',u'MLPid',u'MLname',Apnm )

    def User(self, Ext=''):
        return sq.wxsqltxt(self.DBF,u" select * from security %s" %Ext)

    def Access(self, Ext=''):
        return sq.wxsqltxt(self.DBF,u" select * from access %s" %Ext)



class SetData:
    def __init__(self, Table,send, data):
        self.Table = Table
        self.send = send
        self.data = data

    def Additem(self, send, data):
        return sq.wxsqins('Menu2.db', self.Table, send, data)

    def Additem2(self, send, data):
        return sq.wxsqins2('Menu2.db', self.Table, send, data)

    def Upditem(self, send, data):
        return sq.wxsqlup('Menu2.db', self.Table, send, data)

    def Upditem2(self, send, data):
        return sq.wxsqlup2('Menu2.db', self.Table, send, data)

    def Delitem(self, data):
        return sq.wxsqdel('Menu2.db', self.Table, data)





#In the name of GOD
# -*- coding: utf-8 -*-

from .Analiz import *

class Genrate(object):
    def __init__(self,frmname):
        self.imp_pnl = {}
        self.frm_mak = frmname

        self.lin_wrt = ''

    def createFrm(self, filnam):
        self.filnam = filnam
        self.impfil = self.filnam.split('\\')[-1].replace('.py', '')
        #print(self.impfil)
        #pnlfil = Anlzfil(filnam)
        #self.imp_pnl = pnlfil.parsefil()
        #self.GUIpars = pnlfil.getGUIfil()
        #pnlfil.showParse()

        self.gnr_lins()
        with open(self.frm_mak, 'w') as fl:
            fl.writelines(self.lin_wrt)


    def gnr_lins(self):
        line0 = u"#In the name of GOD\n"
        line1 = u"#"*12+u" Description "+u"#"*12+"\n"
        line2 = "##"+" This is a Sample Demo File"+"\n"
        line3 = "##"+" Only four line you can use for"+"\n"
        line4 = "##"+"  Description"+"\n"
        line5 = "##"+"\n"
        line6 = u"#"*15+u" End "+u"#"*15+"\n"
        line7 = u"# -*- coding: utf-8 -*-\n"
        line8 = u"#!usr/bin/env python\n\n"
        self.lin_wrt = line0 + line1 + line2 + line3 + line4 + line5 + line6 + line7 + line8
        self.lin_wrt += self.gnr_imps()
        self.lin_wrt += self.gnr_frm()
        self.lin_wrt += self.gnr_siz()
        self.lin_wrt += self.gnr_min()
        self.lin_wrt += self.gnr_if()


    def gnr_imps(self):
        imprtxt = u"import wx\n"
        imprtxt += u"from  Config.Init import *\n"
        imprtxt += u"import Src.GUI."+self.impfil+" as pnl\n\n"
        return imprtxt

    def gnr_frm(self):
        frmtxt = u"class telframe(wx.Frame):\n"
        frmtxt += u"\tdef __init__(self,parent):\n"
        frmtxt += u"\t\twx.Frame.__init__(self,parent,style=wx.FRAME_FLOAT_ON_PARENT|wx.DEFAULT_FRAME_STYLE)\n"
        frmtxt += u"\t\tself.parent= parent\n\n"

        frmtxt += u"\t\tself.Pnl = pnl.MyPanel1(self)\n\n"

        frmtxt += u"\tdef closeit(self):\n"
        frmtxt += u"\t\tself.Close(True)\n\n"

        return frmtxt

    def gnr_siz(self):
        sizdef = u"def size():\n"
        sizdef += u"\treturn (-1,-1)\n\n"
        return sizdef
    def gnr_min(self):
        mindef = u"def main(panel=None ):\n"
        mindef += u"\tparent =  panel.GetParent()\n\n"
        mindef += u"\tframe = telframe(parent )\n"
        mindef += u"\tframe.SetTitle(u'form')\n"
        mindef += u"\tframe.SetSize(size())\n"
        mindef += u"\tframe.Show()\n\n"
        return mindef

    def gnr_if(self):
        iffil = u"if __name__ == '__main__':\n"
        iffil += u"\tmain()\n"
        return iffil


class Genrate2(object):
    def __init__(self,pronam):
        self.pronam = pronam
        self.addlin = ''

    def appendFile(self):
        with open(self.pronam,'a+', encoding='utf-8') as Prg:
            Prg.writelines(self.addlin)

    def gnratLine(self, Frame=True, Size=True, Main=True, Ifit=True, Framname= 'telframe' , Title= 'Form'):
        if Frame:
            self.addlin += self.grplin1creat()

        if Size:
            self.addlin += self.grplin2creat()

        if Main:
            self.addlin += self.grplin3creat(Framname,Title)

        if Ifit:
            self.addlin += self.grplin4creat()

    def grplin1creat(self):
        frmtxt = u"class telframe(wx.Frame):\n"
        frmtxt += u"\tdef __init__(self,parent):\n"
        frmtxt += u"\t\twx.Frame.__init__(self,parent,style=wx.FRAME_FLOAT_ON_PARENT|wx.DEFAULT_FRAME_STYLE)\n"
        frmtxt += u"\t\tself.parent= parent\n\n"

        frmtxt += u"\t\tself.Pnl = pnl.MyPanel1(self)\n\n"

        frmtxt += u"\tdef closeit(self):\n"
        frmtxt += u"\t\tself.Close(True)\n\n"

        return frmtxt

    def grplin2creat(self):
        sizdef = u"def size():\n"
        sizdef += u"\treturn (-1,-1)\n\n"
        return sizdef

    def grplin3creat(self, Fram_name, Titel):
        mindef = u"def main(panel=None ):\n"
        mindef += u"\tparent =  panel.GetParent()\n\n"
        mindef += u"\tframe = %s(parent )\n"%Fram_name
        mindef += u"\tframe.SetTitle(u'%s')\n"%Titel
        mindef += u"\tframe.SetSize(size())\n"
        mindef += u"\tframe.Show()\n\n"
        return mindef

    def grplin4creat(self):
        iffil = u"if __name__ == '__main__':\n"
        iffil += u"\tmain()\n"
        return iffil


class GenrDemo(Genrate):
    def __init__(self,mypath):
        Genrate.__init__(self,mypath+'\\Demo.py')
        self.createFrm('SamPnl.py')






# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## You Can Edit This File : This is wrong >>> PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
import wx.grid

###########################################################################
## Class MyPanel1
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 640,450 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		Sb1 = wx.StaticBoxSizer( wx.StaticBox( self, wx.ID_ANY, u"label" ), wx.VERTICAL )

		self.titr = wx.StaticText( Sb1.GetStaticBox(), wx.ID_ANY, u"This is a DEMO", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.titr.Wrap( -1 )

		self.titr.SetFont( wx.Font( 45, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, False, wx.EmptyString ) )

		Sb1.Add( self.titr, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )


		Hsz1.Add( Sb1, 1, wx.EXPAND, 5 )


		Vsz1.Add( Hsz1, 0, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.fld = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz2.Add( self.fld, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chosChoices = []
		self.chos = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chosChoices, 0 )
		self.chos.SetSelection( 0 )
		Hsz2.Add( self.chos, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.chk = wx.CheckBox( self, wx.ID_ANY, u"Check Me!", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz2.Add( self.chk, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.rdio = wx.RadioButton( self, wx.ID_ANY, u"RadioBtn", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz2.Add( self.rdio, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.sldr = wx.Slider( self, wx.ID_ANY, 50, 0, 100, wx.DefaultPosition, wx.DefaultSize, wx.SL_HORIZONTAL )
		Hsz2.Add( self.sldr, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.gug = wx.Gauge( self, wx.ID_ANY, 100, wx.DefaultPosition, wx.DefaultSize, wx.GA_HORIZONTAL )
		self.gug.SetValue( 0 )
		Hsz2.Add( self.gug, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz2, 0, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn = wx.Button( self, wx.ID_ANY, u"MyButton", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.btn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.bmbtn = wx.BitmapButton( self, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		Hsz3.Add( self.bmbtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.tgbtn = wx.ToggleButton( self, wx.ID_ANY, u"Toggle me!", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.tgbtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.timpkr = wx.TimePickerCtrl( self, wx.ID_ANY, wx.DefaultDateTime, wx.DefaultPosition, wx.DefaultSize, wx.TP_DEFAULT )
		Hsz3.Add( self.timpkr, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fntpkr = wx.FontPickerCtrl( self, wx.ID_ANY, wx.NullFont, wx.DefaultPosition, wx.DefaultSize, wx.FNTP_DEFAULT_STYLE )
		self.fntpkr.SetMaxPointSize( 100 )
		Hsz3.Add( self.fntpkr, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.spnbtn = wx.SpinButton( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.spnbtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.dirpkr = wx.DirPickerCtrl( self, wx.ID_ANY, wx.EmptyString, u"Select a folder", wx.DefaultPosition, wx.DefaultSize, wx.DIRP_DEFAULT_STYLE|wx.DIRP_SMALL )
		Hsz3.Add( self.dirpkr, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz3, 0, wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.TCR = wx.TreeCtrl( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TR_DEFAULT_STYLE )
		Hsz4.Add( self.TCR, 0, wx.ALL|wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.grd = wx.grid.Grid( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )

		# Grid
		self.grd.CreateGrid( 5, 5 )
		self.grd.EnableEditing( True )
		self.grd.EnableGridLines( True )
		self.grd.EnableDragGridSize( False )
		self.grd.SetMargins( 0, 0 )

		# Columns
		self.grd.EnableDragColMove( False )
		self.grd.EnableDragColSize( True )
		self.grd.SetColLabelSize( 30 )
		self.grd.SetColLabelAlignment( wx.ALIGN_CENTER, wx.ALIGN_CENTER )

		# Rows
		self.grd.EnableDragRowSize( True )
		self.grd.SetRowLabelSize( 80 )
		self.grd.SetRowLabelAlignment( wx.ALIGN_CENTER, wx.ALIGN_CENTER )

		# Label Appearance

		# Cell Defaults
		self.grd.SetDefaultCellAlignment( wx.ALIGN_LEFT, wx.ALIGN_TOP )
		Hsz4.Add( self.grd, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz4, 0, wx.EXPAND, 5 )

		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )

		self.notbok = wx.Notebook( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )
		self.P1 = wx.Panel( self.notbok, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		self.notbok.AddPage( self.P1, u"a page", False )
		self.P2 = wx.Panel( self.notbok, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		self.notbok.AddPage( self.P2, u"a page", False )
		self.P3 = wx.Panel( self.notbok, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		self.notbok.AddPage( self.P3, u"a page", True )

		Hsz5.Add( self.notbok, 1, wx.EXPAND|wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.chsbok = wx.Choicebook( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.CHB_DEFAULT )
		self.P4 = wx.Panel( self.chsbok, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		self.chsbok.AddPage( self.P4, u"a page", False )
		self.P5 = wx.Panel( self.chsbok, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		self.chsbok.AddPage( self.P5, u"a page", True )
		Hsz5.Add( self.chsbok, 1, wx.EXPAND|wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz5, 1, wx.EXPAND, 5 )

		Hsz6 = wx.BoxSizer(wx.HORIZONTAL)

		self.btnq = wx.Button(self, wx.ID_ANY, u"Close", wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz6.Add(self.btnq, 0, wx.ALL, 5)

		Vsz1.Add(Hsz6, 0, wx.ALIGN_CENTER_HORIZONTAL, 5)

		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.btnq.Bind(wx.EVT_BUTTON, self.closit)

	def __del__( self ):
		pass

	# Virtual event handlers, overide them in your derived class
	def closit(self, event):
		q = self.GetParent()
		q.Close()




#In the name of God
# -*- coding: utf-8 -*-
#!usr/bin/env python

from wx.py import frame,filling,pseudo
import re

class Anlzfil(object):
    def __init__(self, pyFile):
        self.pyFile = pyFile
        self.imprts = []
        self.objcts = {}
        self.pmodls = {}

    def parsefil(self):
        with open(self.pyFile, 'r', encoding=u'utf-8') as fpy:
            linsred = fpy.readlines()
            d = 1
            for ln in linsred:
                if 'import' in ln:
                    #print(ln)
                    self.imprts.append(ln)
                if 'class' in ln:
                    #print(ln)
                    i = pseudo.PseudoFile.readline(self.pyFile)
                    #print(dir(i))
                    self.objcts['class'] = ln
                if 'def' in ln:

                    self.pmodls['def'+str(d)] = ln
                    d = d + 1

    def showParse(self):
        print(self.imprts,self.objcts,self.pmodls)

    def hasDesc(self):
        with open(self.pyFile,'r', encoding=u'utf-8') as f:
            txt = f.read()
        whris = re.search(r'############ Description ############',txt)
        whrhs = re.findall(r'^#{12,}.Desc.*#{12,}\n##.*.*\n##.*.*\n##.*.*\n##.*.*\n#{15,}.End.#{15,}',txt,re.MULTILINE)
        #print(whrhs,whris)
        if whris:
            return whrhs[0]


    def getGUIfil(self):
        for im in self.imprts:
            if 'Src' in im:
                return im[im.find('GUI'):].split(' ')[0]

    def checkSyntx(self):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris = re.search(r"if\s__name__\s==\s\'__main__\':", f.read())
            whmis = re.search(r'(.+main.+)||[main]',f.read())
            #print(whris.group().split(' '))
            if whris:
                mainis = re.search(r'def\smain',f.read())
                mainis2= re.search(r'...\smain\s\(panel.+\)\:',f.read())
                #print(u'main found:',mainis,mainis2)
            #print(whmis)
            return whris

    def checkSyntx2(self):
        '''
        A : if __name__=='__main__': stetement
        B : def main(panel=None): statement
        C : class telframe(wx.Frame): statemenr
        D : class MyPanel1(wx.Panel): statement
        :return: A,B,C,D
        '''
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            txt = f.read()
        whris = re.findall(r"if\s__name__\s?==\s?\'__main__\'\s?:", txt)
        #print('if __name__',whris)
        A = len(whris)
        mainis2 = re.findall(r'def\smain\(panel.+\)\:|def\smain\s?\(\s?panel.+\)\:', txt)
        #print('main(panel=None)', mainis2)
        B = len(mainis2)
        whfis = re.findall(r'class\s.+\(\s?wx\.Frame.+:',txt)
        #print('wx.Frame',whfis)
        C = len(whfis)

        panlis = re.findall(r'class\sMyPanel1\s?\(\s?wx\.Panel.+:',txt)
        #print('class wx.Panel',panlis)
        D = len(panlis)
        #     return False
        return A,B,C,D


    def ishasmain(self):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris = re.search(r'def\smain', f.read())
            if whris:
                #print(whris.group().split(' '))
                return whris.group().split(' ')[1]

    def ishasifin(self):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            #whris = re.search(r"if\s__name__", f.read())
            whris = re.search(r"if\s__name__\s?==\s?\'__main__\'\s?:", f.read())
            if whris:
                #print(whris.group().split(' '))
                return whris.group().split(' ')[1]

    def ishasframe(self):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris = re.search(r'class\s.*\s?(\s?wx\.Frame\s?).+', f.read())
            if whris:
                #print(whris.group().split(' ')[1])
                return whris.group().split(' ')[1]

    def ishaspanel(self):
        with open(self.pyFile, 'r' , encoding=u'utf-8') as f:
            whris = re.search(r"class\s.*\s?(\s?wx\.Panel\s?)", f.read())
            if whris:
                #print(whris.group().split(' ')[1])
                return whris.group().split(' ')[1]

    def ishasimport(self, txt=''):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris = re.findall(r'import\s+%s.+\s+'%txt, f.read())
            if whris :
                #print(whris)
                return whris
    def ishasfromim(self, txt=''):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris2 = re.findall(r'from\s+%s.+\s+import\s+.+'%txt, f.read())
            if whris2:
                #print(whris2)
                return whris2

    def ismainexist(self, txt=''):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris2 = re.findall(r'main',f.read())
            #print(whris2)
            if whris2:
                return whris2
    def iswxframeexist(self, txt=''):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris2 = re.findall(r'wx\.Frame',f.read())
            #print(whris2)
            if whris2:
                return whris2

    def isDBimexist(self, txt=''):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            whris2 = re.findall(r'import\s+Database\.PostGet\s+as\s+PG',f.read())
            if whris2:
                return whris2

    def isFiledbexist(self, txt=''):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            itxt = f.read()
        whris1 = re.findall(r'\s+PG\.Get2\s?\(.*.\)',itxt)
        whris2 = re.findall(r'\s+PG\.Post2\s?\(.*.\)',itxt)

        if whris1 or whris2:
            return whris1,whris2

    def findDBintxt(self, txt):
        whris1 = re.findall(r'\'.*.\\Src\\DBF\\.*.\'', txt)
        if whris1:
            dbfile = whris1[0].replace("'",'').replace(',','')
            #print(dbfile)
            return dbfile
        else:
            whris1 = re.findall(r'\(\'.*.\',',txt)
            #print(whris1)
            if whris1:
                dbfile = whris1[0].replace("'",'').replace(',','').replace('(','')
                #print(dbfile)
                return dbfile

    def indexImpline(self):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            itxt = f.readlines()
        i = 0
        imprtlist = []
        for t in itxt:
            i += 1
            if 'import' in t:
                imprtlist.append((t,i))
        return imprtlist

    def hasMLAimpis(self, txt=''):
        with open(self.pyFile, 'r', encoding=u'utf-8') as f:
            itxt = f.readlines()
        whris1 = whris2 = []

        for linn in itxt:
            if linn[:6] == 'import':
                #print(re.findall('Src\.MLA\..*.', linn),linn)
                if re.findall('Src\.MLA\..*.', linn):
                    whris1.append(linn)

            if linn[:4] == 'from':
                #print(re.findall('Src\.MLA\..*.', linn), linn)
                if re.findall('Src\.MLA\..*.', linn):
                    whris2.append(linn)

        #whris1 = re.search(r'^[import]\s+Src\.MLA\..*.',itxt)
        #whris1 = re.match(r'import\s+Src\.MLA\..*.', itxt)
        #whris2 = re.search(r'^[from]\s+Src\.MLA\..*.',itxt)
        #print(whris2,whris1)
        if whris1 or whris2:
            return whris1,whris2

def GetPanelImport(filewopy):
    f = filewopy+'.py'

def AnalizdbText(dbdatatxt):
    Table_feild_dict = {}
    Index_List = []
    wtxt1 = re.sub(r'[\(\n\)]','',dbdatatxt)
    #print(wtxt1)
    wtxt = re.sub(r'\s+',' ',wtxt1)
    #print(wtxt)
    ltxt = wtxt.split(' ')
    #print(ltxt)
    Table_name = ltxt[ltxt.index('TABLE') + 1]

    t = dbdatatxt
    fld = t[t.find('(')+1:t.find(')')]
    t1 = re.sub(r'\s+',' ',fld)
    #print(t1.replace('\n','').split(','))
    t2 = t1.replace('\n','').split(',')
    #print(t2)
    ifilds = []
    for fll in t2:
        #Table_feild_dict[Table_name]=(fll.split(' ')[0],fll.split(' ')[1])
        ifilds.append(fll)
    Table_feild_dict[Table_name] = ifilds
    return Table_feild_dict

def AnalizdbText2(dbtext):
    Table_list = {}
    Index_list = {}
    for txt in dbtext:
        if txt[0] == 'table':
            f = txt[4][txt[4].index('(')+1:txt[4].index(')',-1)]
            #print(re.sub(r'\s+', ' ', f))
            sbf = re.sub(r'\s+', ' ', f)
            fields = []
            #print(sbf.split(','))
            for sfld in sbf.split(','):
                #print(sfld.strip(' ')[:7])
                if sfld.strip(' ')[:7] == 'PRIMARY' or ')' in sfld.strip(' ').split(' ')[0]:
                    print(sfld)
                else:
                    fields.append(sfld)
            #fields = re.split(',',re.sub('\s+',' ',f))
            #print(fields)
            lstfld = []
            for fl in fields:
                ssfl = ''
                ssfl = fl.strip(' ').split(' ')
                #print(ssfl)
                if len(ssfl) > 0:
                    namfld = ssfl[0]
                    if len(ssfl) > 1:
                        typfld = ssfl[1]
                        if len(ssfl) > 2:
                            stgfld = ssfl[2:]
                        else:
                            stgfld = []
                    else:
                        typfld = "TEXT"
                #print(namfld,typfld,stgfld)
                lstfld.append((namfld,typfld,stgfld))
            Table_list[txt[1]] = lstfld

        if txt[0] == 'index':
            #Index_list[txt[1]]
            pass
    return Table_list,Index_list


#In the name of GOD
#Supervised Learning
#Regresion Problem Normal Equesion
# -*- coding: utf-8 -*-
#!usr/bin/env python

import numpy as np
from matplotlib import pyplot as plot
from mpl_toolkits.mplot3d import Axes3D

class Normal_Equa:
	def __init__(self):
		pass

	def Comput_Theta(self, X_Matrix, y_Matrix):
		Theta = []
		m = np.size(X_Matrix[:,1])
		
		step1 = np.dot(X_Matrix.T, X_Matrix)
		step2 = np.linalg.pinv(step1)
		step3 = np.dot(step2, X_Matrix.T)
		Theta = np.dot(step3 ,y_Matrix.T)

		#Theta = np.dot(np.linalg.inv(np.dot(X_Matrix.T, X_Matrix)), np.dot(X_Matrix.T, y_Matrix))

		return Theta






# In the name of God
# -*- coding: utf-8 -*-
# Windows and Panels main Frame File
#! /usr/bin/env python

import wx
import Database.wxsq as DB
#import Database.wxsq as SQ
from GUI.proman import Mymenu,DoProgram2

class MyPanel1(wx.Panel):
    def __init__(self,parent,id,pos,size,style):
        wx.Panel.__init__ ( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 142,396 ), style = wx.TAB_TRAVERSAL )

        self.parent = parent
        
        inmenu = Mymenu()

        #lbl = inmenu.Revitm()
                    
        self.btn = []
        VSiz = wx.BoxSizer( wx.VERTICAL )
        '''
        i = 0
        for b in lbl:
            if b[0] != None:
                self.btn.append( wx.Button( self, b[1], str(b[0]), wx.DefaultPosition, wx.DefaultSize, 0 ))
                VSiz.Add( self.btn[i], 0, wx.ALL, 5 )
                #self.btn[i].Bind( wx.EVT_BUTTON, self.onbtn  )
                i +=1
            else:
                self.line = wx.StaticLine( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL )
                VSiz.Add( self.line, 0, wx.EXPAND |wx.ALL, 5 )

        '''
        
    
        self.SetSizer( VSiz )
        self.Layout()
